@@ -18,6 +18,8 @@
 #include <zypp/ExternalProgram.h>
 #include <zypp/TmpPath.h>
 #include <zypp/PathInfo.h>
+#include <zypp-core/zyppng/base/private/linuxhelpers_p.h>
+
 #include "WebServer.h"
 
 #include <thread>
@@ -63,7 +65,7 @@ namespace  {
     AutoDispose<int> sockfd { socket( AF_INET, SOCK_STREAM, 0 ) };
     if ( sockfd < 0 ) {
         std::cerr << "ERROR opening socket" << endl;
-	return ret;
+        return ret;
     }
     sockfd.setDispose( ::close );
 
@@ -101,7 +103,7 @@ static inline std::string handlerPrefix()
   return pref;
 }
 
-WebServer::Request::Request( std::istream::__streambuf_type *rinbuf, std::ostream::__streambuf_type *routbuf, std::ostream::__streambuf_type *rerrbuf )
+WebServer::Request::Request(std::streambuf *rinbuf, std::streambuf *routbuf, std::streambuf *rerrbuf )
   : rin  ( rinbuf )
   , rout ( routbuf )
   , rerr ( rerrbuf )
@@ -206,7 +208,7 @@ public:
         bool canContinue = ( zypp::filesystem::symlink( Pathname(TESTS_SRC_DIR)/"data"/"nginxconf"/"nginx.conf",  confFile ) == 0 );
         if ( canContinue ) canContinue = writeConfFile( confPath / "srvroot.conf", str::Format("root    %1%;") % _docroot );
         if ( canContinue ) canContinue = writeConfFile( confPath / "fcgisock.conf", str::Format("fastcgi_pass unix:%1%;") % socketPath().c_str() );
-	if ( canContinue ) canContinue = writeConfFile( confPath / "user.conf", getuid() != 0 ? "" : "user root;" );
+        if ( canContinue ) canContinue = writeConfFile( confPath / "user.conf", getuid() != 0 ? "" : "user root;" );
         if ( canContinue ) {
           if ( _ssl )
             canContinue = writeConfFile( confPath / "port.conf", str::Format("listen    %1% ssl;") % _port );
@@ -254,21 +256,21 @@ public:
           std::cerr << line << endl;
         };
 
-	// Wait max 10 sec for the socket becoming available
-	bool isup { checkLocalPort( port() ) };
-	if ( !isup )
-	{
-	  unsigned i = 0;
-	  do {
-	    std::this_thread::sleep_for( std::chrono::milliseconds(1000) );
-	    isup = checkLocalPort( port() );
-	  } while ( !isup && ++i < 10 );
+        // Wait max 10 sec for the socket becoming available
+        bool isup { checkLocalPort( port() ) };
+        if ( !isup )
+        {
+          unsigned i = 0;
+          do {
+            std::this_thread::sleep_for( std::chrono::milliseconds(1000) );
+            isup = checkLocalPort( port() );
+          } while ( !isup && ++i < 10 );
 
-	  if ( !isup && prog.running() ) {
-	    prog.kill( SIGTERM );
+          if ( !isup && prog.running() ) {
+            prog.kill( SIGTERM );
             prog.close();
-	  }
-	}
+          }
+        }
 
         if ( !prog.running() ) {
           _stop = true;
@@ -279,7 +281,7 @@ public:
 
         FCGX_Request request;
         FCGX_InitRequest(&request, sockFD,0);
-	AutoDispose<FCGX_Request*> guard( &request, boost::bind( &FCGX_Free, _1, 0 ) );
+        AutoDispose<FCGX_Request*> guard( &request, std::bind( &FCGX_Free, _1, 0 ) );
 
         struct pollfd fds[] { {
             _wakeupPipe[0],
@@ -309,14 +311,10 @@ public:
 
           //there is no way to give a timeout to FCGX_Accept_r, so we poll the socketfd for new
           //connections and listen on a pipe for a wakeup event to stop the worker if required
-          int ret = ::poll( fds, 3, INT_MAX );
-          if ( ret == 0 ) {
-            //timeout just continue the loop condition will stop if required
-            continue;
-          }
+          int ret = zyppng::eintrSafeCall( ::poll, fds, 3, -1 );
 
           if ( ret < 0 ) {
-            std::cerr << "Poll error " << endl;
+            std::cerr << "Poll error " << errno << endl;
             continue;
           }
 
@@ -379,12 +377,12 @@ public:
               //remove "/handler/" prefix
               std::string key = req.params.at("SCRIPT_NAME").substr( handlerPrefix().length() );
 
-              auto it = _handlers.find( key );
+              const auto &it = _handlers.find( key );
               if ( it == _handlers.end() ) {
-                req.rerr << "Status: 404 Not Found\r\n"
-                         << "Content-Type: text/html\r\n"
-                         << "\r\n"
-                         << "Request handler was not found";
+                if ( !_defaultHandler ) {
+                  _defaultHandler = makeDefaultHandler();
+                }
+                _defaultHandler( req );
                 FCGX_Finish_r(&request);
                 continue;
               }
@@ -396,7 +394,7 @@ public:
         }
 
         if ( prog.running() ) {
-            prog.kill( SIGQUIT );
+            prog.kill( SIGTERM );
             prog.close();
         }
     }
@@ -453,6 +451,7 @@ public:
     zypp::Pathname _docroot;
     zypp::shared_ptr<std::thread> _thrd;
     std::map<std::string, WebServer::RequestHandler> _handlers;
+    WebServer::RequestHandler _defaultHandler;
     unsigned int _port;
     int _wakeupPipe[2];
 
@@ -490,6 +489,12 @@ void WebServer::addRequestHandler( const std::string &path, RequestHandler &&han
   _pimpl->_handlers[path] = std::move(handler);
 }
 
+void WebServer::setDefaultHandler ( RequestHandler &&handler )
+{
+  std::lock_guard<std::mutex> lock( _pimpl->_mut );
+  _pimpl->_defaultHandler = std::move(handler);
+}
+
 void WebServer::removeRequestHandler(const std::string &path)
 {
   std::lock_guard<std::mutex> lock( _pimpl->_mut );
@@ -535,6 +540,16 @@ WebServer::RequestHandler WebServer::makeResponse( std::string resp )  {
   };
 };
 
+WebServer::RequestHandler WebServer::makeDefaultHandler( )
+{
+  return []( WebServer::Request & req ){
+    req.rerr  << "Status: 404 Not Found\r\n"
+              << "Content-Type: text/html\r\n"
+              << "\r\n"
+              << "Request handler was not found";
+  };
+}
+
 WebServer::RequestHandler WebServer::makeResponse( std::string status, std::string content )  {
   return makeResponse( status , std::vector<std::string>(), content );
 };
