@@ -29,7 +29,7 @@ public:
     items.push_back( make_pair( t, std::move(loc) ) );
     return true;
   }
-  
+
   std::vector<std::pair<std::string, OnMediaLocation> > items;
 };
 
@@ -38,7 +38,7 @@ BOOST_AUTO_TEST_CASE(repomd_read)
   std::list<Pathname> entries;
   if ( filesystem::readdir( entries, DATADIR, false ) != 0 )
     ZYPP_THROW(Exception("failed to read directory"));
-    
+
   for ( std::list<Pathname>::const_iterator it = entries.begin(); it != entries.end(); ++it )
   {
     Pathname file = *it;
@@ -47,7 +47,23 @@ BOOST_AUTO_TEST_CASE(repomd_read)
       cout << *it << endl;
 
       Collector collect;
-      RepomdFileReader( file, std::ref(collect) );
+      RepomdFileReader r( file, std::ref(collect) );
+      if ( file.basename() == "repomd-1.xml" ) {
+        BOOST_CHECK_EQUAL( r.keywords().size(), 7 );
+        auto keyhints = r.keyhints();
+        BOOST_CHECK_EQUAL( keyhints.size(), 5 );
+        std::map<std::string,std::string> check = {
+          { "gpg-pubkey-39db7c82-5847eb1f.asc", "FEAB502539D846DB2C0961CA70AF9E8139DB7C82" },
+          { "gpg-pubkey-307e3d54-5aaa90a5.asc", "4E98E67519D98DC7362A" },
+          { "gpg-pubkey-65176565-59787af5.asc", "637B32FF" },
+          { "gpg-pubkey-3dbdc284-is OK",        "3dbdc284" },
+          { "gpg-pubkey-feab502539d846db2c0961ca70af9e8139db7c82-is OK as well", "feab502539d846db2c0961ca70af9e8139db7c82" },
+          { "gpg-pubkey-536X4dd4-X is not a hexdigit", "must not occur" },
+        };
+        for ( const auto & hint : keyhints ) {
+          BOOST_CHECK_EQUAL( check[hint.first], hint.second );
+        }
+      }
 
       std::ifstream ifs( file.extend(".solution").asString().c_str() );
 
@@ -55,10 +71,10 @@ BOOST_AUTO_TEST_CASE(repomd_read)
       while ( ifs && !ifs.eof() )
       {
         std::string dtype;
-	getline(ifs, dtype);
-	if ( dtype.empty() )
-	  break;
-	BOOST_REQUIRE( count < collect.items.size() );
+        getline(ifs, dtype);
+        if ( dtype.empty() )
+          break;
+        BOOST_REQUIRE( count < collect.items.size() );
         BOOST_CHECK_EQUAL( collect.items[count].first, dtype );
 
         std::string checksum_type;
@@ -67,7 +83,7 @@ BOOST_AUTO_TEST_CASE(repomd_read)
         getline(ifs, checksum);
         BOOST_CHECK_EQUAL( collect.items[count].second.checksum(), CheckSum(checksum_type, checksum) );
 
-	std::string loc;
+        std::string loc;
         getline(ifs, loc);
         BOOST_CHECK_EQUAL( collect.items[count].second.filename(), Pathname(loc) );
 
