@@ -110,6 +110,8 @@ int main( int argc, char * argv[] )
     message( "Use test system at " + mroot.asString() );
   }
   filesystem::assert_dir( mroot );
+  base::LogControl::instance().logfile( mroot/"ToolScanRepos.log" );
+  message( "Use logfile " + (mroot/"ToolScanRepos.log").asString() );
 
   message( "Use archiecture " + march.asString() );
   TestSetup test( mroot, march );
@@ -131,4 +133,4 @@ int main( int argc, char * argv[] )
 
   INT << "===[END]============================================" << endl << endl;
   return ret;
-}
\ No newline at end of file
+}
