@@ -184,22 +184,12 @@ namespace zyppng {
 
       if ( urlScheme == "https" )
       {
-#if CURLVERSION_AT_LEAST(7,19,4)
         // restrict following of redirections from https to https only
-        if ( _url.getHost() == "download.opensuse.org" ) {
-#if CURLVERSION_AT_LEAST(7,85,0)
-          setCurlOption( CURLOPT_REDIR_PROTOCOLS_STR, "http,https" );
-#else
-          setCurlOption( CURLOPT_REDIR_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS );
-#endif
-        } else {
-#if CURLVERSION_AT_LEAST(7,85,0)
-          setCurlOption( CURLOPT_REDIR_PROTOCOLS_STR, "https" );
-#else
-          setCurlOption( CURLOPT_REDIR_PROTOCOLS, CURLPROTO_HTTPS );
-#endif
+        // but be less restrictive for d.o.o
+        bool allowHttp = ( _url.getHost() == "download.opensuse.org" );
+        if ( :: internal::setCurlRedirProtocols ( _easyHandle, allowHttp ) != CURLE_OK ) {
+          ZYPP_THROW( zypp::media::MediaCurlSetOptException( _url, _errorBuf.data() ) );
         }
-#endif // #if CURLVERSION_AT_LEAST(7,19,4)
 
         if( locSet.verifyPeerEnabled() ||
              locSet.verifyHostEnabled() )
