@@ -14,7 +14,7 @@
 
 #include <iosfwd>
 
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DefaultIntegral>
 #include <zypp/sat/detail/PoolMember.h>
 #include <zypp/Capability.h>
 
@@ -176,7 +176,7 @@ namespace zypp
   {
     for ( const Capability & rhs : *this )
       if ( lhs == rhs )
-	return true;
+        return true;
     return false;
   }
 
@@ -184,7 +184,7 @@ namespace zypp
   {
     for ( const Capability & rhs : *this )
       if ( lhs.matches( rhs ) == CapMatch::yes )
-	return true;
+        return true;
     return false;
   }
   /////////////////////////////////////////////////////////////////
