@@ -23,6 +23,7 @@
 #include <zypp/Capability.h>
 
 #include <zypp/sat/detail/PoolImpl.h>
+#include <zypp/sat/detail/PoolMember.h>
 #include <zypp/sat/Pool.h>
 #include <zypp/ResPool.h>
 
@@ -35,6 +36,19 @@ namespace zypp
   namespace
   { /////////////////////////////////////////////////////////////////
 
+    /// Round Robin string buffer
+    template <unsigned TLen = 5>
+    struct TempStrings
+    {
+      /** Reference to the next (cleared) tempstring. */
+      std::string & getNext()
+      { unsigned c = _next; _next = (_next+1) % TLen; _buf[c].clear(); return _buf[c]; }
+
+    private:
+      unsigned _next = 0;
+      std::string _buf[TLen];
+    };
+
     /** backward skip whitespace starting at pos_r */
     inline std::string::size_type backskipWs( const std::string & str_r, std::string::size_type pos_r )
     {
@@ -175,6 +189,7 @@ namespace zypp
                                     const ResKind & kind_r )
     {
       static const Arch srcArch( IdString(ARCH_SRC).asString() );
+      static const Arch nosrcArch( IdString(ARCH_NOSRC).asString() );
       static const std::string srcKindPrefix( ResKind::srcpackage.asString() + ':' );
 
       // check for an embedded 'srcpackage:foo' to be mapped to 'foo' and 'ResKind::srcpackage'.
@@ -190,7 +205,7 @@ namespace zypp
       if ( asep != std::string::npos )
       {
         Arch ext( name_r.substr( asep+1 ) );
-        if ( ext.isBuiltIn() || ext == srcArch )
+        if ( ext.isBuiltIn() || ext == srcArch || ext == nosrcArch )
         {
           arch = ext;
           name.erase( asep );
@@ -221,6 +236,18 @@ namespace zypp
       return relFromStr( pool_r, arch_r, name, op, ed, kind_r );
     }
 
+    /** Parse richdeps from string, otherwise fall back to the traditional parser. */
+    sat::detail::IdType richOrRelFromStr( sat::detail::CPool * pool_r, const std::string & str_r, const ResKind & prefix_r, Capability::CtorFlag flag_r )
+    {
+      if ( str_r[0] == '(' ) {
+        sat::detail::IdType res { sat::detail::PoolMember::myPool().parserpmrichdep( str_r.c_str() ) };
+        if ( res ) return res;
+        // else: no richdep, so fall back to the ordinary parser which in
+        // case of doubt turns the string into a NAMED cap.
+      }
+      return relFromStr( pool_r, Arch_empty, str_r, prefix_r, flag_r );
+    }
+
     /////////////////////////////////////////////////////////////////
   } // namespace
   ///////////////////////////////////////////////////////////////////
@@ -231,11 +258,11 @@ namespace zypp
   /////////////////////////////////////////////////////////////////
 
   Capability::Capability( const char * str_r, const ResKind & prefix_r, CtorFlag flag_r )
-  : _id( relFromStr( myPool().getPool(), Arch_empty, str_r, prefix_r, flag_r ) )
+  : _id( richOrRelFromStr( myPool().getPool(), str_r, prefix_r, flag_r ) )
   {}
 
   Capability::Capability( const std::string & str_r, const ResKind & prefix_r, CtorFlag flag_r )
-  : _id( relFromStr( myPool().getPool(), Arch_empty, str_r.c_str(), prefix_r, flag_r ) )
+  : _id( richOrRelFromStr( myPool().getPool(), str_r, prefix_r, flag_r ) )
   {}
 
   Capability::Capability( const Arch & arch_r, const char * str_r, const ResKind & prefix_r, CtorFlag flag_r )
@@ -243,7 +270,7 @@ namespace zypp
   {}
 
   Capability::Capability( const Arch & arch_r, const std::string & str_r, const ResKind & prefix_r, CtorFlag flag_r )
-  : _id( relFromStr( myPool().getPool(), arch_r, str_r.c_str(), prefix_r, flag_r ) )
+  : _id( relFromStr( myPool().getPool(), arch_r, str_r, prefix_r, flag_r ) )
   {}
 
   Capability::Capability( const char * str_r, CtorFlag flag_r, const ResKind & prefix_r )
@@ -307,9 +334,118 @@ namespace zypp
   : _id( ::pool_rel2id( myPool().getPool(), asIdString(namespace_r).id(), (value_r.empty() ? STRID_NULL : value_r.id() ), REL_NAMESPACE, /*create*/true ) )
   {}
 
+  ///////////////////////////////////////////////////////////////////
+  // https://rpm-software-management.github.io/rpm/manual/boolean_dependencies.html
+  namespace
+  {
+    inline const char * opstr( int op_r )
+    {
+      switch ( op_r )
+      {
+        case REL_GT:               return " > ";
+        case REL_EQ:               return " = ";
+        case REL_LT:               return " < ";
+        case REL_GT|REL_EQ:        return " >= ";
+        case REL_LT|REL_EQ:        return " <= ";
+        case REL_GT|REL_LT:        return " != ";
+        case REL_GT|REL_LT|REL_EQ: return " <=> ";
+        case REL_AND:              return " and ";
+        case REL_OR:               return " or ";
+        case REL_COND:             return " if ";
+        case REL_UNLESS:           return " unless ";
+        case REL_ELSE:             return " else ";
+        case REL_WITH:             return " with ";
+        case REL_WITHOUT:          return " without ";
+      }
+      return "UNKNOWNCAPREL";
+    }
+
+    inline bool isBoolOp( int op_r )
+    {
+      switch ( op_r ) {
+        case REL_AND:
+        case REL_OR:
+        case REL_COND:
+        case REL_UNLESS:
+        case REL_ELSE:
+        case REL_WITH:
+        case REL_WITHOUT:
+          return true;
+      }
+      return false;
+    }
+
+    inline bool needsBrace( int op_r, int parop_r )
+    {
+      return ( isBoolOp( parop_r ) || parop_r == 0 ) && isBoolOp( op_r )
+      && ( parop_r != op_r || op_r == REL_COND || op_r == REL_UNLESS || op_r == REL_ELSE )
+      && not ( ( parop_r == REL_COND || parop_r == REL_UNLESS ) && op_r == REL_ELSE );
+    }
+
+    void cap2strHelper( std::string & outs_r, sat::detail::CPool * pool_r, sat::detail::IdType id_r, int parop_r )
+    {
+      if ( ISRELDEP(id_r) ) {
+        ::Reldep * rd = GETRELDEP( pool_r, id_r );
+        int op = rd->flags;
+
+        if ( op == CapDetail::CAP_ARCH ) {
+          if ( rd->evr == ARCH_SRC || rd->evr == ARCH_NOSRC ) {
+            // map arch .{src,nosrc} to kind srcpackage
+            outs_r += ResKind::srcpackage.c_str();
+            outs_r += ":";
+            outs_r += IdString(rd->name).c_str();
+            return;
+          }
+          cap2strHelper( outs_r, pool_r, rd->name, op );
+          outs_r += ".";
+          cap2strHelper( outs_r, pool_r, rd->evr, op );
+          return;
+        }
+
+        if ( op == CapDetail::CAP_NAMESPACE ) {
+          cap2strHelper( outs_r, pool_r, rd->name, op );
+          outs_r += "(";
+          cap2strHelper( outs_r, pool_r, rd->evr, op );
+          outs_r += ")";
+          return;
+        }
+
+        if ( op == REL_FILECONFLICT )
+        {
+          cap2strHelper( outs_r, pool_r, rd->name, op );
+          return;
+        }
+
+        if ( needsBrace( op, parop_r ) ) {
+          outs_r += "(";
+          cap2strHelper( outs_r, pool_r, rd->name, op );
+          outs_r += opstr( op );
+          cap2strHelper( outs_r, pool_r, rd->evr, op );
+          outs_r += ")";
+          return;
+        }
+
+        cap2strHelper( outs_r, pool_r, rd->name, op );
+        outs_r += opstr( op );
+        cap2strHelper( outs_r, pool_r, rd->evr, op );
+      }
+      else
+        outs_r += IdString(id_r).c_str();
+    }
+  } // namespace
+  ///////////////////////////////////////////////////////////////////
 
   const char * Capability::c_str() const
-  { return( _id ? ::pool_dep2str( myPool().getPool(), _id ) : "" ); }
+  {
+    if ( not id() ) return "";
+    if ( not ISRELDEP(id()) ) return IdString(id()).c_str();
+
+    static TempStrings<5> tempstrs;   // Round Robin buffer to prolong the lifetime of the returned char*
+
+    std::string & outs { tempstrs.getNext() };
+    cap2strHelper( outs, myPool().getPool(), id(), 0 );
+    return outs.c_str();
+  }
 
   CapMatch Capability::_doMatch( sat::detail::IdType lhs,  sat::detail::IdType rhs )
   {
@@ -396,8 +532,8 @@ namespace zypp
       // require name part matching a pool items name (not just provides!)
       if ( pool.byIdentBegin( detail.name() ) != pool.byIdentEnd( detail.name() ) )
       {
-	rewrote_r = true;
-	return guesscap;
+        rewrote_r = true;
+        return guesscap;
       }
 
       // try the one but last '-'
@@ -413,10 +549,10 @@ namespace zypp
 
           // require name part matching a pool items name (not just provides!)
           if ( pool.byIdentBegin( detail.name() ) != pool.byIdentEnd( detail.name() ) )
-	  {
-	    rewrote_r = true;
-	    return guesscap;
-	  }
+          {
+            rewrote_r = true;
+            return guesscap;
+          }
         }
       }
     }
@@ -438,12 +574,12 @@ namespace zypp
   */
   std::ostream & operator<<( std::ostream & str, const Capability & obj )
   {
-    return str << obj.detail();
+    return str << obj.c_str();
   }
 
   std::ostream & dumpOn( std::ostream & str, const Capability & obj )
   {
-    return str << obj.detail();
+    return str << ( obj ? ::pool_dep2str( sat::Pool::instance().get(), obj.id() ) : "" );
   }
 
   ///////////////////////////////////////////////////////////////////
@@ -497,7 +633,7 @@ namespace zypp
       return;
     }
     // map back libsolvs pseudo arch 'src' to kind srcpackage
-    if ( _archIfSimple == ARCH_SRC )
+    if ( _archIfSimple == ARCH_SRC || _archIfSimple == ARCH_NOSRC )
     {
       _lhs = IdString( (ResKind::srcpackage.asString() + ":" + IdString(_lhs).c_str()).c_str() ).id();
       _archIfSimple = 0;
@@ -517,34 +653,44 @@ namespace zypp
       case CapDetail::NOCAP:
         return str << "<NoCap>";
         break;
+
       case CapDetail::NAMED:
         str << obj.name();
         if ( obj.hasArch() )
           str << archsep << obj.arch();
         return str;
         break;
+
       case CapDetail::VERSIONED:
         str << obj.name();
         if ( obj.hasArch() )
           str << archsep << obj.arch();
         return str << " " << obj.op() << " " << obj.ed();
         break;
+
       case CapDetail::EXPRESSION:
-        switch ( obj.capRel() )
-        {
-          case CapDetail::REL_NONE:
-          case CapDetail::CAP_AND:
-          case CapDetail::CAP_OR:
-          case CapDetail::CAP_WITH:
-          case CapDetail::CAP_ARCH:
-            return str << obj.lhs().detail() << " " << obj.capRel() << " " << obj.rhs().detail();
-            break;
-          case CapDetail::CAP_NAMESPACE:
-            return str << obj.lhs().detail() << "(" << obj.rhs().detail() << ")";
+      {
+        std::string outs;
+        auto pool = sat::Pool::instance().get();
+        auto op = obj.capRel();
+        if ( obj.capRel() == CapDetail::CAP_NAMESPACE ) {
+          cap2strHelper( outs, pool, obj.lhs().id(), op );
+          outs += "(";
+          cap2strHelper( outs, pool, obj.rhs().id(), op );
+          outs += ")";
         }
-        break;
+        else {
+          outs += "(";
+          cap2strHelper( outs, pool, obj.lhs().id(), op );
+          outs += opstr( op );
+          cap2strHelper( outs, pool, obj.rhs().id(), op );
+          outs += ")";
+        }
+        return str << outs;
+      }
+      break;
     }
-    return str <<  "<UnknownCap>";
+    return str <<  "<UnknownCap(" << obj.lhs() << " " << obj.capRel() << " " << obj.rhs() << ")>";
   }
 
   std::ostream & operator<<( std::ostream & str, CapDetail::Kind obj )
@@ -564,13 +710,17 @@ namespace zypp
     switch ( obj )
     {
       case CapDetail::REL_NONE:      return str << "NoCapRel"; break;
-      case CapDetail::CAP_AND:       return str << "&"; break; // AND
-      case CapDetail::CAP_OR:        return str << "|"; break; // OR
-      case CapDetail::CAP_WITH:      return str << "+"; break; // WITH
+      case CapDetail::CAP_AND:       return str << "and"; break;        // &
+      case CapDetail::CAP_OR:        return str << "or"; break;         // |
+      case CapDetail::CAP_COND:      return str << "if"; break;
+      case CapDetail::CAP_UNLESS:    return str << "unless"; break;
+      case CapDetail::CAP_ELSE:      return str << "else"; break;
+      case CapDetail::CAP_WITH:      return str << "with"; break;       // +
+      case CapDetail::CAP_WITHOUT:   return str << "without"; break;    // -
       case CapDetail::CAP_NAMESPACE: return str << "NAMESPACE"; break;
       case CapDetail::CAP_ARCH:      return str << "ARCH"; break;
    }
-    return str << "UnknownCapRel";
+   return str << "UnknownCapRel("+str::numstring(obj)+")";
   }
 
   /////////////////////////////////////////////////////////////////
