@@ -40,10 +40,10 @@ namespace zypp
   //
   /** A sat capability.
    *
-   * A Capability: <tt>"name[.arch] [op edition]"</tt>
+   * A Capability: <tt>"name[.arch] [op edition]"</tt> or a \c richdep[1]
    *
    * If a certain \ref ResKind is specified upon construction, the
-   * capabilities name part is prefixed, unless it already conatins a
+   * capabilities name part is prefixed, unless it already contains a
    * well known kind spec. If no \ref ResKind is specified, it's assumed
    * you refer to a package or the name is already prefixed:
    * \code
@@ -55,6 +55,9 @@ namespace zypp
    * Capability( "pattern:foo", ResKind::package ) ==> 'pattern:foo'
    * Capability( "package:foo", ResKind::pattern ) ==> 'foo'
    * \endcode
+   *
+   * [1] https://rpm-software-management.github.io/rpm/manual/boolean_dependencies.html
+   * \see \ref CapDetail
    */
   class Capability: protected sat::detail::PoolMember
   {
@@ -72,10 +75,17 @@ namespace zypp
       */
       //@{
       /** Ctor from string.
+       * \a str_r is parsed to see if it forms a richdep. Subsequent arguments are meaningless
+       * in that case. If it's no richdep we continue as described below.
+       *
        * \a str_r is parsed to check whether it contains an <tt>[op edition]</tt> part,
        * unless the \ref PARSED flag is passed to the ctor. In that case <tt>"name[.arch]"</tt>
        * is assumed.
-      */
+       *
+       * \ref Capability legacy is to parse everything unknown into a \ref NAMED
+       * cap. This is often used to turn user supplied search strings with an optional
+       * edition range restriction into \ref PoolQuery arguments ('/gcc[0-9]+/ >= 8').
+       */
       explicit Capability( const char * str_r, const ResKind & prefix_r = ResKind(), CtorFlag flag_r = UNPARSED );
       /** \overload */
       explicit Capability( const std::string & str_r, const ResKind & prefix_r = ResKind(), CtorFlag flag_r = UNPARSED );
@@ -201,7 +211,7 @@ namespace zypp
 
       /** \ref matches functor.
        */
-      struct Matches: public std::binary_function<Capability,Capability,CapMatch>
+      struct Matches
       {
         CapMatch operator()( const Capability & lhs, const Capability & rhs ) const
         { return Capability::matches( lhs, rhs ); }
@@ -291,9 +301,10 @@ namespace zypp
    * \endcode
    * or formed by some \c EXPRESSION:
    * \code
-   *   left_cap op right_cap
-   *   with op := AND|OR|WITH|NAMESPACE
+   *   ( left_cap op right_cap )
+   *   with op := and|or|if|unless|else|with|without
    * \endcode
+   *
    */
   class CapDetail: protected sat::detail::PoolMember
   {
@@ -311,12 +322,19 @@ namespace zypp
       */
       enum CapRel
       {
-        REL_NONE      = 0,
-        CAP_AND       = 16,
-        CAP_OR        = 17,
-        CAP_WITH      = 18,
-        CAP_NAMESPACE = 19,
-        CAP_ARCH      = 20
+        REL_NONE      = 0,  ///< Not an expression
+        CAP_AND       = 16, ///< \c and
+        CAP_OR        = 17, ///< \c or
+
+        CAP_COND      = 22, ///< \c if
+        CAP_UNLESS    = 29, ///< \c unless
+        CAP_ELSE      = 26, ///< \c else
+
+        CAP_WITH      = 18, ///< \c with
+        CAP_WITHOUT   = 28, ///< \c without
+
+        CAP_NAMESPACE = 19, ///<
+        CAP_ARCH      = 20, ///< Used internally
       };
 
     public:
@@ -343,7 +361,7 @@ namespace zypp
       bool     hasArch()  const { return _archIfSimple; }
       IdString arch()     const { return _archIfSimple ? IdString( _archIfSimple ) : IdString(); }
       IdString name()     const { return isSimple()    ? IdString( _lhs ) : IdString(); }
-      Rel      op()       const { return isVersioned() ? Rel( _flag )     : Rel::ANY; }
+      Rel      op()       const { return isVersioned() ? Rel( _flag )     : isSimple() ? Rel::ANY : Rel::NONE; }
       Edition  ed()       const { return isVersioned() ? Edition( _rhs )  : Edition(); }
       //@}
 
