@@ -157,7 +157,7 @@ namespace zypp
       /** \ref match functor.
        * \see \ref RelCompare.
        */
-      struct Match: public std::binary_function<Edition,Edition,int>
+      struct Match
       {
         int operator()( const Edition & lhs, const Edition & rhs ) const
         { return Edition::match( lhs, rhs ); }
@@ -181,10 +181,10 @@ namespace zypp
   /** \relates Edition XML output. */
   inline std::ostream & dumpAsXmlOn( std::ostream & str, const Edition & obj )
   { return str << "<edition"
-	       << " epoch=\"" << obj.epoch() << "\""
-	       << " version=\"" << obj.version() << "\""
-	       << " release=\"" << obj.release() << "\""
-	       << "/>";
+               << " epoch=\"" << obj.epoch() << "\""
+               << " version=\"" << obj.version() << "\""
+               << " release=\"" << obj.release() << "\""
+               << "/>";
   }
 
   /////////////////////////////////////////////////////////////////
