@@ -18,17 +18,18 @@
 #include <zypp/base/LogControl.h>
 #include <zypp/base/LogTools.h>
 #include <zypp/base/PtrTypes.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DefaultIntegral>
 #include <zypp/base/String.h>
+#include <zypp-media/MediaException>
 #include <zypp/Fetcher.h>
 #include <zypp/ZYppFactory.h>
 #include <zypp/CheckSum.h>
-#include <zypp/base/UserRequestException.h>
+#include <zypp-core/base/UserRequestException>
 #include <zypp/parser/susetags/ContentFileReader.h>
 #include <zypp/parser/susetags/RepoIndex.h>
 
 #undef ZYPP_BASE_LOGGER_LOGGROUP
-#define ZYPP_BASE_LOGGER_LOGGROUP "zypp:fetcher"
+#define ZYPP_BASE_LOGGER_LOGGROUP "zypp::fetcher"
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -67,7 +68,7 @@ namespace zypp
       if ( lhs->location.medianr() == rhs->location.medianr() )
         return lhs->location.filename() < rhs->location.filename();
       //else
-        return lhs->location.medianr() < rhs->location.medianr();
+      return lhs->location.medianr() < rhs->location.medianr();
     }
   };
 
@@ -90,9 +91,8 @@ namespace zypp
     ZYPP_DECLARE_FLAGS(Flags, Flag);
 
 
-    FetcherJob( const OnMediaLocation &loc, const Pathname dfile = Pathname())
+    FetcherJob( const OnMediaLocation &loc )
       : location(loc)
-      , deltafile(dfile)
       , flags(None)
     {
       //MIL << location << endl;
@@ -104,7 +104,6 @@ namespace zypp
     }
 
     OnMediaLocation location;
-    Pathname deltafile;
     //CompositeFileChecker checkers;
     std::list<FileChecker> checkers;
     Flags flags;
@@ -141,9 +140,12 @@ namespace zypp
     void enqueueDigestedDir( const OnMediaLocation &resource, bool recursive, const FileChecker &checker = FileChecker() );
 
     void enqueue( const OnMediaLocation &resource, const FileChecker &checker = FileChecker()  );
-    void enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker = FileChecker(), const Pathname &deltafile = Pathname() );
+    void enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker = FileChecker() );
     void addCachePath( const Pathname &cache_dir );
     void reset();
+    void setMediaSetAccess ( MediaSetAccess &media );
+    void start( const Pathname &dest_dir,
+                const ProgressData::ReceiverFnc &progress );
     void start( const Pathname &dest_dir,
                 MediaSetAccess &media,
                 const ProgressData::ReceiverFnc & progress_receiver );
@@ -227,14 +229,19 @@ namespace zypp
     // cache of dir contents
     std::map<std::string, filesystem::DirContent> _dircontent;
 
+    MediaSetAccess * _mediaSetAccess = nullptr;
+
     Fetcher::Options _options;
   };
   ///////////////////////////////////////////////////////////////////
 
-  void Fetcher::Impl::enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker, const Pathname &deltafile )
+  void Fetcher::Impl::enqueueDigested( const OnMediaLocation &resource, const FileChecker & )
   {
+    if ( _mediaSetAccess )
+      _mediaSetAccess->precacheFiles( {resource} );
+
     FetcherJob_Ptr job;
-    job.reset(new FetcherJob(resource, deltafile));
+    job.reset(new FetcherJob(resource));
     job->flags |= FetcherJob:: AlwaysVerifyChecksum;
     _resources.push_back(job);
   }
@@ -284,6 +291,9 @@ namespace zypp
 
   void Fetcher::Impl::enqueue( const OnMediaLocation &resource, const FileChecker &checker )
   {
+    if ( _mediaSetAccess )
+      _mediaSetAccess->precacheFiles( {resource} );
+
     FetcherJob_Ptr job;
     job.reset(new FetcherJob(resource));
     if ( checker )
@@ -306,6 +316,11 @@ namespace zypp
     _dircontent.clear();
   }
 
+  void Fetcher::Impl::setMediaSetAccess( MediaSetAccess &media )
+  {
+    _mediaSetAccess = &media;
+  }
+
   void Fetcher::Impl::addCachePath( const Pathname &cache_dir )
   {
     PathInfo info(cache_dir);
@@ -350,9 +365,9 @@ namespace zypp
       cacheLocation = cacheDir / resource_r.filename();
       if ( PathInfo(cacheLocation).isExist() && is_checksum( cacheLocation, resource_r.checksum() ) )
       {
-	MIL << "file " << resource_r.filename() << " found in cache " << cacheDir << endl;
-	swap( ret, cacheLocation );
-	return ret;
+        MIL << "file " << resource_r.filename() << " found in cache " << cacheDir << endl;
+        swap( ret, cacheLocation );
+        return ret;
       }
     }
 
@@ -376,11 +391,11 @@ namespace zypp
     }
     catch ( const FileCheckException &e )
     {
-      ZYPP_RETHROW(e);
+      throw;  // let known exceptions bypass  silently
     }
     catch ( const Exception &e )
     {
-      ZYPP_RETHROW(e);
+      throw; // slet known exceptions bypass  silently
     }
     catch (...)
     {
@@ -395,24 +410,24 @@ namespace zypp
   {
       auto fnc_addIfInContent( [&]( const std::string & index_r ) -> bool
       {
-	if ( find( content.begin(), content.end(), filesystem::DirEntry(index_r,filesystem::FT_FILE) ) == content.end() )
-	  return false;
-	// add the index of this directory
-	OnMediaLocation indexloc( resource );
-	indexloc.changeFilename( resource.filename() + index_r );
-	addIndex( indexloc );
-	// we need to read it now
-	downloadAndReadIndexList( media, dest_dir );
-	return true;
+        if ( find( content.begin(), content.end(), filesystem::DirEntry(index_r,filesystem::FT_FILE) ) == content.end() )
+          return false;
+        // add the index of this directory
+        OnMediaLocation indexloc( resource );
+        indexloc.changeFilename( resource.filename() + index_r );
+        addIndex( indexloc );
+        // we need to read it now
+        downloadAndReadIndexList( media, dest_dir );
+        return true;
       } );
 
       if ( _options & AutoAddChecksumsIndexes )
       {
-	fnc_addIfInContent( "CHECKSUMS" ) || fnc_addIfInContent( "SHA1SUMS" );
+        fnc_addIfInContent( "CHECKSUMS" ) || fnc_addIfInContent( "SHA1SUMS" );
       }
       if ( _options & AutoAddContentFileIndexes )
       {
-	fnc_addIfInContent( "content" );
+        fnc_addIfInContent( "content" );
       }
   }
 
@@ -448,13 +463,13 @@ namespace zypp
       MIL << "Adding directory " << resource.filename() << endl;
       filesystem::DirContent content;
       try {
-	getDirectoryContent(media, resource, content);
+        getDirectoryContent(media, resource, content);
       }
       catch ( media::MediaFileNotFoundException & exception )
       {
-	ZYPP_CAUGHT( exception );
-	WAR << "Skiping subtree hidden at " << resource.filename() << endl;
-	return;
+        ZYPP_CAUGHT( exception );
+        WAR << "Skipping subtree hidden at " << resource.filename() << endl;
+        return;
       }
 
       // this method test for the option flags so indexes are added
@@ -515,9 +530,9 @@ namespace zypp
       Pathname tmpFile = locateInCache( resource, destDir_r );
       if ( tmpFile.empty() )
       {
-	MIL << "Not found in cache, retrieving..." << endl;
-	tmpFile = media_r.provideFile( resource, resource.optional() ? MediaSetAccess::PROVIDE_NON_INTERACTIVE : MediaSetAccess::PROVIDE_DEFAULT, jobp_r->deltafile );
-	releaseFileGuard.reset( new MediaSetAccess::ReleaseFileGuard( media_r, resource ) ); // release it when we leave the block
+        MIL << "Not found in cache, retrieving..." << endl;
+        tmpFile = media_r.provideFile( resource, resource.optional() ? MediaSetAccess::PROVIDE_NON_INTERACTIVE : MediaSetAccess::PROVIDE_DEFAULT );
+        releaseFileGuard.reset( new MediaSetAccess::ReleaseFileGuard( media_r, resource ) ); // release it when we leave the block
       }
 
       // The final destination: locateInCache also checks destFullPath!
@@ -525,35 +540,35 @@ namespace zypp
       // care it gets deleted, in case the validation fails.
       ManagedFile destFullPath( destDir_r / resource.filename() );
       if ( tmpFile == destFullPath )
-	destFullPath.setDispose( filesystem::unlink );
+        destFullPath.setDispose( filesystem::unlink );
 
       // validate the file (throws if not valid)
       validate( tmpFile, jobp_r->checkers );
 
       // move it to the final destination
       if ( tmpFile == destFullPath )
-	destFullPath.resetDispose();	// keep it!
+        destFullPath.resetDispose();	// keep it!
       else
       {
-	if ( assert_dir( destFullPath->dirname() ) != 0 )
-	  ZYPP_THROW( Exception( "Can't create " + destFullPath->dirname().asString() ) );
+        if ( assert_dir( destFullPath->dirname() ) != 0 )
+          ZYPP_THROW( Exception( "Can't create " + destFullPath->dirname().asString() ) );
 
-	if ( filesystem::hardlinkCopy( tmpFile, destFullPath ) != 0 )
-	  ZYPP_THROW( Exception( "Can't hardlink/copy " + tmpFile.asString() + " to " + destDir_r.asString() ) );
+        if ( filesystem::hardlinkCopy( tmpFile, destFullPath ) != 0 )
+          ZYPP_THROW( Exception( "Can't hardlink/copy " + tmpFile.asString() + " to " + destDir_r.asString() ) );
       }
     }
     catch ( Exception & excpt )
     {
       if ( resource.optional() )
       {
-	ZYPP_CAUGHT( excpt );
-	WAR << "optional resource " << resource << " could not be transferred." << endl;
-	return;
+        ZYPP_CAUGHT( excpt );
+        WAR << "optional resource " << resource << " could not be transferred." << endl;
+        return;
       }
       else
       {
-	excpt.remember( "Can't provide " + resource.filename().asString() );
-	ZYPP_RETHROW( excpt );
+        excpt.remember( "Can't provide " + resource.filename().asString() );
+        ZYPP_RETHROW( excpt );
       }
     }
   }
@@ -602,24 +617,24 @@ namespace zypp
       std::ifstream in( index.c_str() );
       if ( ! in.fail() )
       {
-	  std::string buffer;
+          std::string buffer;
           while ( getline( in, buffer ) )
           {
 
-	      if ( buffer[0] == '#' )
-		continue;	// simple comment
+              if ( buffer[0] == '#' )
+                continue;	// simple comment
 
-	      CheckSum checksum( str::stripFirstWord( buffer, /*ltrim before strip*/true ) );
-	      if ( checksum.empty() )
-		continue;	// empty line | unknown cheksum format
+              CheckSum checksum( str::stripFirstWord( buffer, /*ltrim before strip*/true ) );
+              if ( checksum.empty() )
+                continue;	// empty line | unknown cheksum format
 
-	      if ( buffer.empty() )
-	      {
-		WAR << "Missing filename in CHECKSUMS file: " << index.asString() << " (" << checksum << ")" << endl;
-		continue;
-	      }
+              if ( buffer.empty() )
+              {
+                WAR << "Missing filename in CHECKSUMS file: " << index.asString() << " (" << checksum << ")" << endl;
+                continue;
+              }
 
-	      _checksums[(basedir/buffer).asString()] = checksum;
+              _checksums[(basedir/buffer).asString()] = checksum;
           }
       }
       else
@@ -679,7 +694,7 @@ namespace zypp
  }
 
   // this method takes all the user pointed indexes, gets them and also tries to
-  // download their signature, and verify them. After that, its parses each one
+  // download their signature, and verify them. After that, it parses each one
   // to fill the checksum cache.
   void Fetcher::Impl::downloadAndReadIndexList( MediaSetAccess &media, const Pathname &dest_dir)
   {
@@ -711,12 +726,22 @@ namespace zypp
       MIL << "done reading indexes" << endl;
   }
 
+  void Fetcher::Impl::start( const Pathname &dest_dir,
+                             const ProgressData::ReceiverFnc & progress )
+  {
+    if ( !_mediaSetAccess )
+      ZYPP_THROW( zypp::Exception("Called Fetcher::start without setting MediaSetAccess before.") );
+    start( dest_dir, *_mediaSetAccess, progress );
+  }
+
   // start processing all fetcher jobs.
   // it processes any user pointed index first
   void Fetcher::Impl::start( const Pathname &dest_dir,
                              MediaSetAccess &media,
                              const ProgressData::ReceiverFnc & progress_receiver )
   {
+    _mediaSetAccess = nullptr; //reset the internally stored MediaSetAccess
+
     ProgressData progress(_resources.size());
     progress.sendTo(progress_receiver);
 
@@ -830,7 +855,12 @@ namespace zypp
 
   void Fetcher::enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker, const Pathname &deltafile )
   {
-    _pimpl->enqueueDigested(resource, checker, deltafile);
+    enqueueDigested( OnMediaLocation(resource).setDeltafile(deltafile), checker );
+  }
+
+  void Fetcher::enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker )
+  {
+    _pimpl->enqueueDigested( resource, checker );
   }
 
   void Fetcher::enqueueDir( const OnMediaLocation &resource,
@@ -859,6 +889,7 @@ namespace zypp
     _pimpl->enqueue(resource, checker);
   }
 
+
   void Fetcher::addCachePath( const Pathname &cache_dir )
   {
     _pimpl->addCachePath(cache_dir);
@@ -869,6 +900,16 @@ namespace zypp
     _pimpl->reset();
   }
 
+  void Fetcher::setMediaSetAccess( MediaSetAccess &media )
+  {
+    _pimpl->setMediaSetAccess( media );
+  }
+
+  void Fetcher::start(const zypp::filesystem::Pathname &dest_dir, const ProgressData::ReceiverFnc &progress)
+  {
+    _pimpl->start( dest_dir, progress );
+  }
+
   void Fetcher::start( const Pathname &dest_dir,
                        MediaSetAccess &media,
                        const ProgressData::ReceiverFnc & progress_receiver )
