@@ -19,11 +19,11 @@
 #include <zypp/base/PtrTypes.h>
 #include <zypp/Pathname.h>
 #include <zypp/Url.h>
-#include <zypp/OnMediaLocation.h>
+#include <zypp-core/OnMediaLocation>
 #include <zypp/Digest.h>
 #include <zypp/MediaSetAccess.h>
 #include <zypp/FileChecker.h>
-#include <zypp/ProgressData.h>
+#include <zypp-core/ui/ProgressData>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -197,15 +197,17 @@ namespace zypp
     * the user could be asked twice.
     *
     * \todo FIXME implement checker == operator to avoid this.
-    *
-    * the optional deltafile argument describes a file that can
-    * be used for delta download algorithms. Usable files are
-    * uncompressed files or files compressed with gzip --rsyncable.
-    * Other files like rpms do not work, as the compression
-    * breaks the delta algorithm.
     */
-    void enqueueDigested( const OnMediaLocation &resource,
-                          const FileChecker &checker = FileChecker(), const Pathname &deltafile = Pathname());
+     void enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker = FileChecker() );
+
+
+    /**
+      * \deprecated
+      * the deltafile argument is part of OnMediaLocation now, please use \ref enqueueDigested without the
+      * deltafile argument
+      */
+    ZYPP_DEPRECATED void enqueueDigested( const OnMediaLocation &resource,
+                          const FileChecker &checker, const Pathname &deltafile );
 
 
     /**
@@ -307,6 +309,25 @@ namespace zypp
      */
     void reset();
 
+    /**
+     * Sets the media set access that will be used to precache and
+     * to download the files when \ref start is called. Calling \ref start
+     * will reset the media access.
+     */
+    void setMediaSetAccess ( MediaSetAccess &media );
+
+    /**
+    * start the transfer to a destination directory
+    * \a dest_dir
+    * The media has to be provides with \ref setMediaSetAccess before
+    * calling this version of start.
+    * The file tree will be replicated inside this
+    * directory
+    *
+    */
+    void start( const Pathname &dest_dir,
+      const ProgressData::ReceiverFnc & progress = ProgressData::ReceiverFnc() );
+
     /**
     * start the transfer to a destination directory
     * \a dest_dir
