@@ -15,6 +15,7 @@
 #include <zypp/base/PtrTypes.h>
 #include <zypp/Pathname.h>
 #include <zypp/PublicKey.h>
+#include <zypp-core/ByteArray.h>
 
 #include <memory>
 
@@ -31,29 +32,29 @@ namespace zypp
 class KeyManagerCtx
 {
     public:
-	/** Creates a new KeyManagerCtx for PGP using a volatile temp. homedir/keyring.
-	 *
-	 * Mainly used with methods, which need a context but do not need a keyring
-	 * (like \ref readKeyFromFile or \ref readSignatureFingerprints).
-	 *
-	 * \note The underlying keyring is intentionally NOT the users keyring.
-	 * Think of it as a volatile keyring whose content may get cleared anytime.
-	 *
-	 * \throws KeyRingException if context can not be created or set up
-	 */
-	static KeyManagerCtx createForOpenPGP();
+        /** Creates a new KeyManagerCtx for PGP using a volatile temp. homedir/keyring.
+         *
+         * Mainly used with methods, which need a context but do not need a keyring
+         * (like \ref readKeyFromFile or \ref readSignatureFingerprints).
+         *
+         * \note The underlying keyring is intentionally NOT the users keyring.
+         * Think of it as a volatile keyring whose content may get cleared anytime.
+         *
+         * \throws KeyRingException if context can not be created or set up
+         */
+        static KeyManagerCtx createForOpenPGP();
 
-	/** Creates a new KeyManagerCtx for PGP using a custom homedir/keyring.
-	 *
-	 * \note If you explicitly pass an empty \c Pathname, no homedir/keyring
-	 * will be set and GPGME will use it's defaults.
-	 *
-	 * \throws KeyRingException if context can not be created or set up
-	 */
-	static KeyManagerCtx createForOpenPGP( const Pathname & keyring_r );
+        /** Creates a new KeyManagerCtx for PGP using a custom homedir/keyring.
+         *
+         * \note If you explicitly pass an empty \c Pathname, no homedir/keyring
+         * will be set and GPGME will use its defaults.
+         *
+         * \throws KeyRingException if context can not be created or set up
+         */
+        static KeyManagerCtx createForOpenPGP( const Pathname & keyring_r );
 
-	/** Return the homedir/keyring. */
-	Pathname homedir() const;
+        /** Return the homedir/keyring. */
+        Pathname homedir() const;
 
         /**  Returns a list of all public keys found in the current keyring */
         std::list<PublicKeyData> listKeys();
@@ -70,12 +71,18 @@ class KeyManagerCtx
         /** Tries to import a key from \a keyfile, returns true on success */
         bool importKey(const Pathname & keyfile);
 
+        /** Tries to import a key from \a buffer, returns true on success */
+        bool importKey(const ByteArray & keydata);
+
         /** Tries to delete a key specified by \a id, returns true on success */
         bool deleteKey (const std::string & id);
 
         /** Reads all fingerprints from the \a signature file , returns a list of all found fingerprints */
         std::list<std::string> readSignatureFingerprints(const Pathname & signature);
 
+        /** Reads all fingerprints from the \a buffer, returns a list of all found fingerprints */
+        std::list<std::string> readSignatureFingerprints( const ByteArray & keyData );
+
     private:
       KeyManagerCtx();
 
