@@ -11,6 +11,7 @@
 */
 #include <iostream>
 #include <fstream>
+#include <optional>
 #include <sys/file.h>
 #include <cstdio>
 #include <unistd.h>
@@ -24,7 +25,7 @@
 #include <zypp/base/String.h>
 #include <zypp/base/Regex.h>
 #include <zypp/base/Gettext.h>
-#include <zypp/base/WatchFile.h>
+#include <zypp-core/fs/WatchFile>
 #include <zypp/PathInfo.h>
 #include <zypp/KeyRing.h>
 #include <zypp/ExternalProgram.h>
@@ -98,6 +99,17 @@ namespace zypp
     report(data);
   }
 
+  void KeyRingReport::reportAutoImportKey( const std::list<PublicKeyData> & keyDataList_r,
+                                           const PublicKeyData & keySigning_r,
+                                           const KeyContext &keyContext_r )
+  {
+    UserData data { REPORT_AUTO_IMPORT_KEY };
+    data.set( "KeyDataList", keyDataList_r );
+    data.set( "KeySigning",  keySigning_r );
+    data.set( "KeyContext",  keyContext_r );
+    report( data );
+  }
+
   namespace
   {
     ///////////////////////////////////////////////////////////////////
@@ -115,55 +127,90 @@ namespace zypp
       void setDirty( const Pathname & keyring_r )
       { _cacheMap[keyring_r].setDirty(); }
 
+      ///////////////////////////////////////////////////////////////////
+      /// \brief Helper providing on demand a KeyManagerCtx to manip the cached keyring.
+      ///
+      /// The 1st call to \ref keyManagerCtx creates the \ref KeyManagerCtx. Returning
+      /// the context tags the cached data as dirty. Should be used to import/delete keys
+      /// in a cache keyring.
+      struct Manip {
+        NON_COPYABLE_BUT_MOVE( Manip );
+        Manip( CachedPublicKeyData & cache_r, Pathname keyring_r )
+        : _cache { cache_r }
+        , _keyring { std::move(keyring_r) }
+        {}
+
+        KeyManagerCtx & keyManagerCtx() {
+          if ( not _context ) {
+            _context = KeyManagerCtx::createForOpenPGP( _keyring );
+          }
+          // frankly: don't remember why an explicit setDirty was introduced and
+          // why WatchFile was not enough. Maybe some corner case when the keyrings
+          // are created?
+          _cache.setDirty( _keyring );
+          return _context.value();
+        }
+
+      private:
+        CachedPublicKeyData & _cache;
+        Pathname _keyring;
+        std::optional<KeyManagerCtx> _context;
+      };
+      ///////////////////////////////////////////////////////////////////
+
+      /** Helper providing on demand a KeyManagerCtx to manip the cached keyring. */
+      Manip manip( Pathname keyring_r ) { return Manip( *this, std::move(keyring_r) ); }
+
     private:
       struct Cache
       {
-	Cache() {}
+        Cache() {}
 
-	void setDirty()
-	{
-	  _keyringK.reset();
-	  _keyringP.reset();
-	}
+        void setDirty()
+        {
+          _keyringK.reset();
+          _keyringP.reset();
+        }
 
-	void assertCache( const Pathname & keyring_r )
-	{
-	  // .kbx since gpg2-2.1
-	  if ( !_keyringK )
-	    _keyringK.reset( new WatchFile( keyring_r/"pubring.kbx", WatchFile::NO_INIT ) );
-	  if ( !_keyringP )
-	    _keyringP.reset( new WatchFile( keyring_r/"pubring.gpg", WatchFile::NO_INIT ) );
-	}
+        void assertCache( const Pathname & keyring_r )
+        {
+          // .kbx since gpg2-2.1
+          if ( !_keyringK )
+            _keyringK.reset( new WatchFile( keyring_r/"pubring.kbx", WatchFile::NO_INIT ) );
+          if ( !_keyringP )
+            _keyringP.reset( new WatchFile( keyring_r/"pubring.gpg", WatchFile::NO_INIT ) );
+        }
 
-	bool hasChanged() const
-	{
-	  bool k = _keyringK->hasChanged();	// be sure both files are checked
-	  bool p = _keyringP->hasChanged();
-	  return k || p;
-	}
+        bool hasChanged() const
+        {
+          bool k = _keyringK->hasChanged();	// be sure both files are checked
+          bool p = _keyringP->hasChanged();
+          return k || p;
+        }
 
-	std::list<PublicKeyData> _data;
+        std::list<PublicKeyData> _data;
 
       private:
-	scoped_ptr<WatchFile> _keyringK;
-	scoped_ptr<WatchFile> _keyringP;
+
+        scoped_ptr<WatchFile> _keyringK;
+        scoped_ptr<WatchFile> _keyringP;
       };
 
       typedef std::map<Pathname,Cache> CacheMap;
 
       const std::list<PublicKeyData> & getData( const Pathname & keyring_r ) const
       {
-	Cache & cache( _cacheMap[keyring_r] );
-	// init new cache entry
-	cache.assertCache( keyring_r );
-	return getData( keyring_r, cache );
+        Cache & cache( _cacheMap[keyring_r] );
+        // init new cache entry
+        cache.assertCache( keyring_r );
+        return getData( keyring_r, cache );
       }
 
       const std::list<PublicKeyData> & getData( const Pathname & keyring_r, Cache & cache_r ) const
       {
         if ( cache_r.hasChanged() ) {
-	  cache_r._data = KeyManagerCtx::createForOpenPGP( keyring_r ).listKeys();
-	  MIL << "Found keys: " << cache_r._data  << endl;
+          cache_r._data = KeyManagerCtx::createForOpenPGP( keyring_r ).listKeys();
+          MIL << "Found keys: " << cache_r._data  << endl;
         }
         return cache_r._data;
       }
@@ -171,6 +218,8 @@ namespace zypp
       mutable CacheMap _cacheMap;
     };
     ///////////////////////////////////////////////////////////////////
+
+
   }
 
   ///////////////////////////////////////////////////////////////////
@@ -217,19 +266,34 @@ namespace zypp
     PublicKey exportTrustedPublicKey( const PublicKeyData & keyData )
     { return exportKey( keyData, trustedKeyRing() ); }
 
-    bool verifyFileSignatureWorkflow( const Pathname & file, const std::string & filedesc, const Pathname & signature, bool & sigValid_r, const KeyContext & keycontext = KeyContext());
+    bool verifyFileSignatureWorkflow( keyring::VerifyFileContext & context_r )
+    {
+      // Assert result and return value are in sync
+      context_r.fileAccepted( _verifyFileSignatureWorkflow( context_r ) );
+      return context_r.fileAccepted();
+    }
+    bool _verifyFileSignatureWorkflow( keyring::VerifyFileContext & context_r );
 
     bool verifyFileSignature( const Pathname & file, const Pathname & signature )
     { return verifyFile( file, signature, generalKeyRing() ); }
     bool verifyFileTrustedSignature( const Pathname & file, const Pathname & signature )
     { return verifyFile( file, signature, trustedKeyRing() ); }
 
+    PublicKeyData publicKeyExists( const std::string & id )
+    { return publicKeyExists(id, generalKeyRing());}
     PublicKeyData trustedPublicKeyExists( const std::string & id )
     { return publicKeyExists(id, trustedKeyRing());}
 
     bool provideAndImportKeyFromRepositoryWorkflow (const std::string &id_r , const RepoInfo &info_r );
 
+    void allowPreload( bool yesno_r )
+    { _allowPreload = yesno_r; }
+
   private:
+    /** Impl helper providing on demand a KeyManagerCtx to manip a cached keyring. */
+    CachedPublicKeyData::Manip keyRingManip( const Pathname & keyring )
+    { return cachedPublicKeyData.manip( keyring ); }
+
     bool verifyFile( const Pathname & file, const Pathname & signature, const Pathname & keyring );
     void importKey( const Pathname & keyfile, const Pathname & keyring );
 
@@ -249,6 +313,8 @@ namespace zypp
 
     /** Get \ref PublicKeyData for ID (\c false if ID is not found). */
     PublicKeyData publicKeyExists( const std::string & id, const Pathname & keyring );
+    /** Load key files cached on the system into the generalKeyRing. */
+    void preloadCachedKeys();
 
     const Pathname generalKeyRing() const
     { return _general_tmp_dir.path(); }
@@ -259,6 +325,7 @@ namespace zypp
     filesystem::TmpDir _trusted_tmp_dir;
     filesystem::TmpDir _general_tmp_dir;
     Pathname _base_dir;
+    bool _allowPreload = false;	//< General keyring may be preloaded with keys cached on the system.
 
   private:
     /** Functor returning the keyrings data (cached).
@@ -277,16 +344,16 @@ namespace zypp
     {
       void operator()( const PublicKey & key_r )
       {
-	try {
-	  _rpmdbEmitSignal->trustedKeyAdded( key_r );
-	  _emitSignal->trustedKeyAdded( key_r );
-	}
-	catch ( const Exception & excp )
-	{
-	  ERR << "Could not import key into rpmdb: " << excp << endl;
-	  // TODO: JobReport as hotfix for bsc#1057188; should bubble up and go through some callback
-	  JobReport::error( excp.asUserHistory() );
-	}
+        try {
+          _rpmdbEmitSignal->trustedKeyAdded( key_r );
+          _emitSignal->trustedKeyAdded( key_r );
+        }
+        catch ( const Exception & excp )
+        {
+          ERR << "Could not import key into rpmdb: " << excp << endl;
+          // TODO: JobReport as hotfix for bsc#1057188; should bubble up and go through some callback
+          JobReport::error( excp.asUserHistory() );
+        }
       }
 
     private:
@@ -306,14 +373,14 @@ namespace zypp
       ImportKeyCBHelper emitSignal;
       if ( key.hiddenKeys().empty() )
       {
-	emitSignal( key );
+        emitSignal( key );
       }
       else
       {
-	// multiple keys: Export individual keys ascii armored to import in rpmdb
-	emitSignal( exportKey( key, trustedKeyRing() ) );
-	for ( const PublicKeyData & hkey : key.hiddenKeys() )
-	  emitSignal( exportKey( hkey, trustedKeyRing() ) );
+        // multiple keys: Export individual keys ascii armored to import in rpmdb
+        emitSignal( exportKey( key, trustedKeyRing() ) );
+        for ( const PublicKeyData & hkey : key.hiddenKeys() )
+          emitSignal( exportKey( hkey, trustedKeyRing() ) );
       }
     }
   }
@@ -354,19 +421,78 @@ namespace zypp
 
   PublicKeyData KeyRing::Impl::publicKeyExists( const std::string & id, const Pathname & keyring )
   {
+    if ( _allowPreload && keyring == generalKeyRing() ) {
+      _allowPreload = false;
+      preloadCachedKeys();
+    }
+
     PublicKeyData ret;
     for ( const PublicKeyData & key : publicKeyData( keyring ) )
     {
       if ( key.providesKey( id ) )
       {
-	ret = key;
-	break;
+        ret = key;
+        break;
       }
     }
-    MIL << (ret ? "Found" : "No") << " key [" << id << "] in keyring " << keyring << endl;
+    DBG << (ret ? "Found" : "No") << " key [" << id << "] in keyring " << keyring << endl;
     return ret;
   }
 
+  void KeyRing::Impl::preloadCachedKeys()
+  {
+    MIL << "preloadCachedKeys into general keyring..." << endl;
+    CachedPublicKeyData::Manip manip { keyRingManip( generalKeyRing() ) }; // Provides the context if we want to manip a cached keyring.
+
+    // For now just load the 'gpg-pubkey-*.{asc,key}' files into the general keyring,
+    // if their id (derived from the filename) is not in the trusted ring.
+    // TODO: Head for a persistent general keyring.
+    std::set<Pathname> cachedirs;
+    ZConfig & conf { ZConfig::instance() };
+    cachedirs.insert( conf.pubkeyCachePath() );
+    cachedirs.insert( "/usr/lib/rpm/gnupg/keys" );
+    if ( Pathname r = conf.systemRoot(); r != "/" && not r.empty() ) {
+      cachedirs.insert( r / conf.pubkeyCachePath() );
+      cachedirs.insert( r / "/usr/lib/rpm/gnupg/keys" );
+    }
+    if ( Pathname r = conf.repoManagerRoot(); r != "/" && not r.empty() ) {
+      cachedirs.insert( r / conf.pubkeyCachePath() );
+      cachedirs.insert( r / "/usr/lib/rpm/gnupg/keys" );
+    }
+
+    std::map<std::string,Pathname> keyCandidates;	// Collect one file path per keyid
+    const str::regex rx { "^gpg-pubkey-([[:xdigit:]]{8,})(-[[:xdigit:]]{8,})?\\.(asc|key)$" };
+    for ( const auto & cache : cachedirs ) {
+      dirForEach( cache,
+                  [&rx,&keyCandidates]( const Pathname & dir_r, const char *const file_r )->bool {
+                    str::smatch what;
+                    if ( str::regex_match( file_r, what, rx ) ) {
+                      Pathname & remember { keyCandidates[what[1]] };
+                      if ( remember.empty() ) {
+                        remember = dir_r / file_r;
+                      }
+                    }
+                    return true;
+                  }
+                );
+    }
+
+    for ( const auto & p : keyCandidates ) {
+      // Avoid checking the general keyring while it is flagged dirty.
+      // Checking the trusted ring is ok, and most keys will be there anyway.
+      const std::string & id { p.first };
+      const Pathname & path { p.second };
+      if ( isKeyTrusted(id) )
+        continue;
+      if ( manip.keyManagerCtx().importKey( path ) ) {
+        DBG << "preload key file " << path << endl;
+      }
+      else {
+        WAR << "Skipping: Can't preload key file " << path << endl;
+      }
+    }
+  }
+
   PublicKey KeyRing::Impl::exportKey( const PublicKeyData & keyData, const Pathname & keyring )
   {
     return PublicKey( dumpPublicKeyToTmp( keyData.id(), keyring ), keyData );
@@ -400,27 +526,54 @@ namespace zypp
     return tmpFile;
   }
 
-  bool KeyRing::Impl::verifyFileSignatureWorkflow( const Pathname & file, const std::string & filedesc, const Pathname & signature, bool & sigValid_r, const KeyContext & context )
+  bool KeyRing::Impl::_verifyFileSignatureWorkflow( keyring::VerifyFileContext & context_r )
   {
-    sigValid_r = false;	// set true if signature is actually successfully validated!
+    context_r.resetResults();
+    const Pathname & file        { context_r.file() };
+    const Pathname & signature   { context_r.signature() };
+    const std::string & filedesc { context_r.shortFile() };
+    const KeyContext & keyContext   { context_r.keyContext() };
 
     callback::SendReport<KeyRingReport> report;
     MIL << "Going to verify signature for " << filedesc << " ( " << file << " ) with " << signature << endl;
 
-    // if signature does not exists, ask user if he wants to accept unsigned file.
+    // if signature does not exists, ask user if they want to accept unsigned file.
     if( signature.empty() || (!PathInfo( signature ).isExist()) )
     {
-      bool res = report->askUserToAcceptUnsignedFile( filedesc, context );
+      bool res = report->askUserToAcceptUnsignedFile( filedesc, keyContext );
       MIL << "askUserToAcceptUnsignedFile: " << res << endl;
       return res;
     }
 
     // get the id of the signature (it might be a subkey id!)
-    std::string id = readSignatureKeyId( signature );
-
+    context_r.signatureId( readSignatureKeyId( signature ) );
+    const std::string & id = context_r.signatureId();
     PublicKeyData foundKey;
     Pathname whichKeyring;
 
+    std::list<PublicKeyData> buddies;	// Could be imported IFF the file is validated by a trusted key
+    for ( const auto & sid : context_r.buddyKeys() ) {
+      if ( not PublicKeyData::isSafeKeyId( sid ) ) {
+        WAR << "buddy " << sid << ": key id is too short to safely identify a gpg key. Skipping it." << endl;
+        continue;
+      }
+      if ( trustedPublicKeyExists( sid ) ) {
+        MIL << "buddy " << sid << ": already in trusted key ring. Not needed." << endl;
+        continue;
+      }
+      auto pk = publicKeyExists( sid );
+      if ( not pk ) {
+        WAR << "buddy " << sid << ": not available in the public key ring. Skipping it." << endl;
+        continue;
+      }
+      if ( pk.providesKey(id) ) {
+        MIL << "buddy " << sid << ": is the signing key. Handled separately." << endl;
+        continue;
+      }
+      MIL << "buddy " << sid << ": candidate for auto import. Remeber it." << endl;
+      buddies.push_back( pk );
+    }
+
     if ( !id.empty() ) {
 
       // does key exists in trusted keyring
@@ -436,19 +589,19 @@ namespace zypp
         {
           // bnc #393160: Comment #30: Compare at least the fingerprint
           // in case an attacker created a key the the same id.
-	  //
-	  // FIXME: bsc#1008325: For keys using subkeys, we'd actually need
-	  // to compare the subkey sets, to tell whether a key was updated.
-	  // because created() remains unchanged if the primary key is not touched.
-	  // For now we wait until a new subkey signs the data and treat it as a
-	  //  new key (else part below).
+          //
+          // FIXME: bsc#1008325: For keys using subkeys, we'd actually need
+          // to compare the subkey sets, to tell whether a key was updated.
+          // because created() remains unchanged if the primary key is not touched.
+          // For now we wait until a new subkey signs the data and treat it as a
+          //  new key (else part below).
           if ( trustedKeyData.fingerprint() == generalKeyData.fingerprint()
-	     && trustedKeyData.created() < generalKeyData.created() )
+             && trustedKeyData.created() < generalKeyData.created() )
           {
             MIL << "Key was updated. Saving new version into trusted keyring: " << generalKeyData << endl;
             importKey( exportKey( generalKeyData, generalKeyRing() ), true );
-	    trustedKeyData = publicKeyExists( id, trustedKeyRing() ); // re-read: invalidated by import?
-	  }
+            trustedKeyData = publicKeyExists( id, trustedKeyRing() ); // re-read: invalidated by import?
+          }
         }
 
         foundKey = trustedKeyData;
@@ -463,7 +616,7 @@ namespace zypp
           MIL << "Key [" << id << "] " << key.name() << " is not trusted" << endl;
 
           // ok the key is not trusted, ask the user to trust it or not
-          KeyRingReport::KeyTrust reply = report->askUserToAcceptKey( key, context );
+          KeyRingReport::KeyTrust reply = report->askUserToAcceptKey( key, keyContext );
           if ( reply == KeyRingReport::KEY_TRUST_TEMPORARILY ||
               reply == KeyRingReport::KEY_TRUST_AND_IMPORT )
           {
@@ -486,10 +639,10 @@ namespace zypp
             return false;
           }
         }
-        else if ( ! context.empty() )
+        else if ( ! keyContext.empty() )
         {
           // try to find the key in the repository info
-          if ( provideAndImportKeyFromRepositoryWorkflow( id, context.repoInfo() ) ) {
+          if ( provideAndImportKeyFromRepositoryWorkflow( id, keyContext.repoInfo() ) ) {
             whichKeyring = trustedKeyRing();
             foundKey = PublicKeyData( publicKeyExists( id, trustedKeyRing() ) );
           }
@@ -499,21 +652,31 @@ namespace zypp
 
     if ( foundKey ) {
       // it exists, is trusted, does it validate?
-      report->infoVerify( filedesc, foundKey, context );
+      context_r.signatureIdTrusted( whichKeyring == trustedKeyRing() );
+      report->infoVerify( filedesc, foundKey, keyContext );
       if ( verifyFile( file, signature, whichKeyring ) )
       {
-        return (sigValid_r=true);	// signature is actually successfully validated!
+        context_r.fileValidated( true );
+        if ( context_r.signatureIdTrusted() && not buddies.empty() ) {
+          // Check for buddy keys to be imported...
+          MIL << "Validated with trusted key: importing buddy list..." << endl;
+          report->reportAutoImportKey( buddies, foundKey, keyContext );
+          for ( const auto & kd : buddies ) {
+            importKey( exportKey( kd, generalKeyRing() ), true );
+          }
+        }
+        return context_r.fileValidated();	// signature is actually successfully validated!
       }
       else
       {
-	bool res = report->askUserToAcceptVerificationFailed( filedesc, exportKey( foundKey, whichKeyring ), context );
-	MIL << "askUserToAcceptVerificationFailed: " << res << endl;
+        bool res = report->askUserToAcceptVerificationFailed( filedesc, exportKey( foundKey, whichKeyring ), keyContext );
+        MIL << "askUserToAcceptVerificationFailed: " << res << endl;
         return res;
       }
     } else {
       // signed with an unknown key...
       MIL << "File [" << file << "] ( " << filedesc << " ) signed with unknown key [" << id << "]" << endl;
-      bool res = report->askUserToAcceptUnknownKey( filedesc, id, context );
+      bool res = report->askUserToAcceptUnknownKey( filedesc, id, keyContext );
       MIL << "askUserToAcceptUnknownKey: " << res << endl;
       return res;
     }
@@ -588,18 +751,18 @@ namespace zypp
     if ( ! PathInfo( keyfile ).isExist() )
       // TranslatorExplanation first %s is key name, second is keyring name
       ZYPP_THROW(KeyRingException( str::Format(_("Tried to import not existent key %s into keyring %s"))
-				   % keyfile.asString()
-				   % keyring.asString() ));
+                                   % keyfile.asString()
+                                   % keyring.asString() ));
 
-    cachedPublicKeyData.setDirty( keyring );
-    if ( ! KeyManagerCtx::createForOpenPGP( keyring ).importKey( keyfile ) )
+    CachedPublicKeyData::Manip manip { keyRingManip( keyring ) }; // Provides the context if we want to manip a cached keyring.
+    if ( ! manip.keyManagerCtx().importKey( keyfile ) )
       ZYPP_THROW(KeyRingException(_("Failed to import key.")));
   }
 
   void KeyRing::Impl::deleteKey( const std::string & id, const Pathname & keyring )
   {
-    cachedPublicKeyData.setDirty( keyring );
-    if ( ! KeyManagerCtx::createForOpenPGP( keyring ).deleteKey( id ) )
+    CachedPublicKeyData::Manip manip { keyRingManip( keyring ) }; // Provides the context if we want to manip a cached keyring.
+    if ( ! manip.keyManagerCtx().deleteKey( id ) )
       ZYPP_THROW(KeyRingException(_("Failed to delete key.")));
   }
 
@@ -639,6 +802,9 @@ namespace zypp
   KeyRing::~KeyRing()
   {}
 
+  void KeyRing::allowPreload( bool yesno_r )
+  { _pimpl->allowPreload( yesno_r ); }
+
 
   void KeyRing::importKey( const PublicKey & key, bool trusted )
   { _pimpl->importKey( key, trusted ); }
@@ -664,14 +830,34 @@ namespace zypp
   std::list<PublicKeyData> KeyRing::trustedPublicKeyData()
   { return _pimpl->trustedPublicKeyData(); }
 
+  PublicKeyData KeyRing::publicKeyData( const std::string &id_r )
+  { return _pimpl->publicKeyExists( id_r ); }
+
   PublicKeyData KeyRing::trustedPublicKeyData(const std::string &id_r)
   { return _pimpl->trustedPublicKeyExists( id_r ); }
 
   bool KeyRing::verifyFileSignatureWorkflow( const Pathname & file, const std::string & filedesc, const Pathname & signature, bool & sigValid_r, const KeyContext & keycontext )
-  { return _pimpl->verifyFileSignatureWorkflow( file, filedesc, signature, sigValid_r, keycontext ); }
+  {
+    sigValid_r = false;	// just in case....
+    keyring::VerifyFileContext context( file, signature );
+    context.shortFile( filedesc );
+    context.keyContext( keycontext );
+    verifyFileSignatureWorkflow( context );
+    sigValid_r = context.fileValidated();
+    return context.fileAccepted();
+  }
 
   bool KeyRing::verifyFileSignatureWorkflow( const Pathname & file, const std::string filedesc, const Pathname & signature, const KeyContext & keycontext )
-  { bool unused; return _pimpl->verifyFileSignatureWorkflow( file, filedesc, signature, unused, keycontext ); }
+  {
+    keyring::VerifyFileContext context( file, signature );
+    context.shortFile( filedesc );
+    context.keyContext( keycontext );
+    verifyFileSignatureWorkflow( context );
+    return context.fileAccepted();
+  }
+
+  bool KeyRing::verifyFileSignatureWorkflow( keyring::VerifyFileContext & context_r )
+  { return _pimpl->verifyFileSignatureWorkflow( context_r ); }
 
   bool KeyRing::verifyFileSignature( const Pathname & file, const Pathname & signature )
   { return _pimpl->verifyFileSignature( file, signature ); }
