@@ -24,7 +24,7 @@
 #include <zypp/base/PtrTypes.h>
 #include <zypp/Locale.h>
 #include <zypp/PublicKey.h>
-#include <zypp/KeyContext.h>
+#include <zypp/KeyRingContexts.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -129,6 +129,24 @@ namespace zypp
      /** \relates reportNonImportedKeys generic reports UserData::type */
      constexpr static const char *KEYS_NOT_IMPORTED_REPORT = "KeyRingReport/KeysNotImported";
 
+
+     /**
+      * Notify that a repository auto imported new package signing keys.
+      *
+      * To auto import new package signing keys, the repositories metadata must be
+      * signed by an already trusted key.
+      *
+      * The UserData object will have the following fields:
+      * UserData::type		\ref REPORT_AUTO_IMPORT_KEY
+      * "KeyDataList"		List of KeyData to import
+      * "KeySigning"		KeyData of signing key
+      * "KeyContext"		The KeyContext
+      */
+     void reportAutoImportKey( const std::list<PublicKeyData> & keyDataList_r,
+                               const PublicKeyData & keySigning_r,
+                               const KeyContext &keyContext_r );
+     /** \relates reportAutoImportKey generic reports UserData::type */
+     constexpr static const char *REPORT_AUTO_IMPORT_KEY = "KeyRingReport/reportAutoImportKey";
   };
 
   struct KeyRingSignals : public callback::ReportBase
@@ -272,6 +290,11 @@ namespace zypp
      */
     std::list<PublicKeyData> trustedPublicKeyData();
 
+    /**
+     * Get a public key's data in the keyring (key data only)
+     */
+    PublicKeyData publicKeyData( const std::string &id );
+
     /**
      * Get a trusted public key's data in the keyring (key data only)
      */
@@ -310,6 +333,10 @@ namespace zypp
     bool verifyFileSignatureWorkflow( const Pathname &file, const std::string &filedesc, const Pathname &signature, bool & sigValid_r, const KeyContext &keycontext = KeyContext());
     /** \overload legacy version without 'bool & sigValid_r' */
     bool verifyFileSignatureWorkflow( const Pathname &file, const std::string filedesc, const Pathname &signature, const KeyContext &keycontext = KeyContext());
+    /** \overload using a \ref keyring::VerifyFileContext to pass and return data.
+     * The preferred API. Returns keyring::VerifyFileContext::fileAccepted.
+     */
+    bool verifyFileSignatureWorkflow( keyring::VerifyFileContext & context_r );
 
     /**
      * Verifies a file against a signature, with no user interaction
@@ -330,6 +357,10 @@ namespace zypp
     /** Dtor */
     ~KeyRing();
 
+  public:
+    /** The general keyring may be populated with known keys stored on the system. */
+    void allowPreload( bool yesno_r );
+
   private:
     /** Pointer to implementation */
     RW_pointer<Impl> _pimpl;
