@@ -18,9 +18,9 @@
 #include <zypp/ZConfig.h>
 #include <zypp/base/Logger.h>
 #include <zypp/media/MediaManager.h>
-#include <zypp/base/UserRequestException.h>
+#include <zypp-core/base/UserRequestException>
 
-#include <zypp/ProgressData.h>
+#include <zypp-core/ui/ProgressData>
 
 namespace zypp
 {
@@ -90,12 +90,12 @@ namespace zypp
   {
     media::MediaManager media_mgr;
     // open the media
-    media::MediaId id = media_mgr.open(url_r);
+    media::MediaAccessId id = media_mgr.open(url_r);
     media_mgr.attach(id);
     Pathname products_file = Pathname("media.1/products");
 
     try  {
-      media_mgr.provideFile (id, products_file);
+      media_mgr.provideFile (id, OnMediaLocation(products_file) );
       products_file = media_mgr.localPath (id, products_file);
       scanProductsFile (products_file, result);
     }
