@@ -12,13 +12,17 @@
 
 #include <zypp/base/LogTools.h>
 #include <zypp/base/Regex.h>
-#include <zypp/base/UserRequestException.h>
+#include <zypp-core/base/UserRequestException>
+#include <zypp-media/MediaException>
 #include <zypp/ZYppCallbacks.h>
 #include <zypp/MediaSetAccess.h>
 #include <zypp/PathInfo.h>
 #include <zypp/TmpPath.h>
 //#include <zypp/source/MediaSetAccessReportReceivers.h>
 
+#undef ZYPP_BASE_LOGGER_LOGGROUP
+#define ZYPP_BASE_LOGGER_LOGGROUP "zypp::fetcher"
+
 using std::endl;
 
 ///////////////////////////////////////////////////////////////////
@@ -49,7 +53,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
     {
       media::MediaManager manager;
       for ( const auto & mm : _medias )
-	manager.close( mm.second );
+        manager.close( mm.second );
     }
     catch(...) {} // don't let exception escape a dtor.
   }
@@ -111,34 +115,35 @@ IMPL_PTR_TYPE(MediaSetAccess);
   struct ProvideFileOperation
   {
     Pathname result;
-    ByteCount expectedFileSize;
-    void operator()( media::MediaAccessId media, const Pathname &file )
+    void operator()( media::MediaAccessId media, const OnMediaLocation &file )
     {
       media::MediaManager media_mgr;
-      media_mgr.provideFile(media, file, expectedFileSize);
-      result = media_mgr.localPath(media, file);
+      media_mgr.provideFile( media, file );
+      result = media_mgr.localPath( media, file.filename() );
     }
   };
 
   struct ProvideDirTreeOperation
   {
     Pathname result;
-    void operator()( media::MediaAccessId media, const Pathname &file )
+    void operator()( media::MediaAccessId media, const OnMediaLocation &file )
     {
+      const auto &fName = file.filename();
       media::MediaManager media_mgr;
-      media_mgr.provideDirTree(media, file);
-      result = media_mgr.localPath(media, file);
+      media_mgr.provideDirTree( media, fName );
+      result = media_mgr.localPath( media, fName );
     }
   };
 
   struct ProvideDirOperation
   {
     Pathname result;
-    void operator()( media::MediaAccessId media, const Pathname &file )
+    void operator()( media::MediaAccessId media, const OnMediaLocation &file )
     {
+      const auto &fName = file.filename();
       media::MediaManager media_mgr;
-      media_mgr.provideDir(media, file);
-      result = media_mgr.localPath(media, file);
+      media_mgr.provideDir( media, fName );
+      result = media_mgr.localPath( media, fName );
     }
   };
 
@@ -149,41 +154,41 @@ IMPL_PTR_TYPE(MediaSetAccess);
         : result(false)
     {}
 
-    void operator()( media::MediaAccessId media, const Pathname &file )
+    void operator()( media::MediaAccessId media, const OnMediaLocation &file )
     {
+      const auto &fName = file.filename();
       media::MediaManager media_mgr;
-      result = media_mgr.doesFileExist(media, file);
+      result = media_mgr.doesFileExist( media, fName );
     }
   };
 
-
+  Pathname MediaSetAccess::provideFile( const OnMediaLocation &resource, ProvideFileOptions options )
+  {
+    ProvideFileOperation op;
+    provide( std::ref(op), resource, options );
+    return op.result;
+  }
 
   Pathname MediaSetAccess::provideFile( const OnMediaLocation & resource, ProvideFileOptions options, const Pathname &deltafile )
   {
-    ProvideFileOperation op;
-    op.expectedFileSize = resource.downloadSize();
-    provide( boost::ref(op), resource, options, deltafile );
-    return op.result;
+    return provideFile( OnMediaLocation( resource ).setDeltafile( deltafile ), options );
   }
 
   Pathname MediaSetAccess::provideFile(const Pathname & file, unsigned media_nr, ProvideFileOptions options )
   {
-    OnMediaLocation resource;
-    ProvideFileOperation op;
-    resource.setLocation(file, media_nr);
-    provide( boost::ref(op), resource, options, Pathname() );
-    return op.result;
+    return provideFile( OnMediaLocation( file, media_nr ), options );
   }
 
   Pathname MediaSetAccess::provideOptionalFile( const Pathname & file, unsigned media_nr )
   {
     try
     {
-      if ( doesFileExist( file, media_nr ) )
-	return provideFile( file, media_nr, PROVIDE_NON_INTERACTIVE );
+      return provideFile( OnMediaLocation( file, media_nr ).setOptional( true ), PROVIDE_NON_INTERACTIVE );
     }
     catch ( const media::MediaFileNotFoundException & excpt_r )
     { ZYPP_CAUGHT( excpt_r ); }
+    catch ( const media::MediaForbiddenException & excpt_r )
+    { ZYPP_CAUGHT( excpt_r ); }
     catch ( const media::MediaNotAFileException & excpt_r )
     { ZYPP_CAUGHT( excpt_r ); }
    return Pathname();
@@ -193,12 +198,14 @@ IMPL_PTR_TYPE(MediaSetAccess);
   {
     Url url(file_url);
     Pathname path(url.getPathName());
+
     url.setPathName ("/");
     MediaSetAccess access(url);
 
     ManagedFile tmpFile = filesystem::TmpFile::asManagedFile();
 
-    Pathname file = access.provideFile(path, 1, options);
+    bool optional = options & PROVIDE_NON_INTERACTIVE;
+    Pathname file = access.provideFile( OnMediaLocation(path, 1).setOptional( optional ), options );
 
     //prevent the file from being deleted when MediaSetAccess gets out of scope
     if ( filesystem::hardlinkCopy(file, tmpFile) != 0 )
@@ -223,18 +230,37 @@ IMPL_PTR_TYPE(MediaSetAccess);
   bool MediaSetAccess::doesFileExist(const Pathname & file, unsigned media_nr )
   {
     ProvideFileExistenceOperation op;
-    OnMediaLocation resource;
-    resource.setLocation(file, media_nr);
-    provide( boost::ref(op), resource, PROVIDE_DEFAULT, Pathname());
+    OnMediaLocation resource(file, media_nr);
+    provide( std::ref(op), resource, PROVIDE_DEFAULT );
     return op.result;
   }
 
+  void MediaSetAccess::precacheFiles(const std::vector<OnMediaLocation> &files)
+  {
+    media::MediaManager media_mgr;
+
+    for ( const auto &resource : files ) {
+      Pathname file(resource.filename());
+      unsigned media_nr(resource.medianr());
+      media::MediaAccessId media = getMediaAccessId( media_nr );
+
+      if ( !media_mgr.isOpen( media ) ) {
+        MIL << "Skipping precache of file " << resource.filename() << " media is not open";
+        continue;
+      }
+
+      if ( ! media_mgr.isAttached(media) )
+        media_mgr.attach(media);
+
+      media_mgr.precacheFiles( media, { resource } );
+    }
+  }
+
   void MediaSetAccess::provide( ProvideOperation op,
                                 const OnMediaLocation &resource,
-                                ProvideFileOptions options,
-                                const Pathname &deltafile )
+                                ProvideFileOptions options )
   {
-    Pathname file(resource.filename());
+    const auto &file(resource.filename());
     unsigned media_nr(resource.medianr());
 
     callback::SendReport<media::MediaChangeReport> report;
@@ -246,7 +272,6 @@ IMPL_PTR_TYPE(MediaSetAccess);
     {
       // get the mediaId, but don't try to attach it here
       media = getMediaAccessId( media_nr);
-      bool deltafileset = false;
 
       try
       {
@@ -255,17 +280,12 @@ IMPL_PTR_TYPE(MediaSetAccess);
         // try to attach the media
         if ( ! media_mgr.isAttached(media) )
           media_mgr.attach(media);
-	media_mgr.setDeltafile(media, deltafile);
-	deltafileset = true;
-        op(media, file);
-	media_mgr.setDeltafile(media, Pathname());
+        op(media, resource);
         break;
       }
       catch ( media::MediaException & excp )
       {
         ZYPP_CAUGHT(excp);
-	if (deltafileset)
-	  media_mgr.setDeltafile(media, Pathname());
         media::MediaChangeReport::Action user = media::MediaChangeReport::ABORT;
         unsigned int devindex = 0;
         std::vector<std::string> devices;
@@ -273,20 +293,6 @@ IMPL_PTR_TYPE(MediaSetAccess);
 
         do
         {
-          if (user != media::MediaChangeReport::EJECT) // no use in calling this again
-          {
-            DBG << "Media couldn't provide file " << file << " , releasing." << endl;
-            try
-            {
-              media_mgr.release(media);
-            }
-            catch (const Exception & excpt_r)
-            {
-                ZYPP_CAUGHT(excpt_r);
-                MIL << "Failed to release media " << media << endl;
-            }
-          }
-
           // set up the reason
           media::MediaChangeReport::Error reason = media::MediaChangeReport::INVALID;
 
@@ -307,9 +313,9 @@ IMPL_PTR_TYPE(MediaSetAccess);
           }
 
           // Propagate the original error if _no_ callback receiver is connected, or
-	  // non_interactive mode (for optional files) is used (except for wrong media).
+          // non_interactive mode (for optional files) is used (except for wrong media).
           if ( ! callback::SendReport<media::MediaChangeReport>::connected()
-	     || (( options & PROVIDE_NON_INTERACTIVE ) && reason != media::MediaChangeReport::WRONG ) )
+             || (( options & PROVIDE_NON_INTERACTIVE ) && reason != media::MediaChangeReport::WRONG ) )
           {
               MIL << "Can't provide file. Non-Interactive mode." << endl;
               ZYPP_RETHROW(excp);
@@ -342,22 +348,22 @@ IMPL_PTR_TYPE(MediaSetAccess);
           else if ( user == media::MediaChangeReport::IGNORE )
           {
             DBG << "Skipping" << endl;
-	    SkipRequestException nexcp("User-requested skipping of a file");
-	    nexcp.remember(excp);
-	    ZYPP_THROW(nexcp);
-	  }
+            SkipRequestException nexcp("User-requested skipping of a file");
+            nexcp.remember(excp);
+            ZYPP_THROW(nexcp);
+          }
           else if ( user == media::MediaChangeReport::EJECT )
           {
             DBG << "Eject: try to release" << endl;
-	    try
-	    {
-	      media_mgr.releaseAll();
-	      media_mgr.release (media, devindex < devices.size() ? devices[devindex] : "");
-	    }
-	    catch ( const Exception & e)
-	    {
-	      ZYPP_CAUGHT(e);
-	    }
+            try
+            {
+              media_mgr.releaseAll();
+              media_mgr.release (media, devindex < devices.size() ? devices[devindex] : "");
+            }
+            catch ( const Exception & e)
+            {
+              ZYPP_CAUGHT(e);
+            }
           }
           else if ( user == media::MediaChangeReport::RETRY  ||
             user == media::MediaChangeReport::CHANGE_URL )
@@ -389,16 +395,15 @@ IMPL_PTR_TYPE(MediaSetAccess);
                                       unsigned media_nr,
                                       ProvideFileOptions options )
   {
-    OnMediaLocation resource;
-    resource.setLocation(dir, media_nr);
+    OnMediaLocation resource(dir, media_nr);
     if ( recursive )
     {
         ProvideDirTreeOperation op;
-        provide( boost::ref(op), resource, options, Pathname());
+        provide( std::ref(op), resource, options );
         return op.result;
     }
     ProvideDirOperation op;
-    provide( boost::ref(op), resource, options, Pathname());
+    provide( std::ref(op), resource, options );
     return op.result;
   }
 
