@@ -11,7 +11,7 @@
 */
 #include <iostream>
 #include <zypp/base/Logger.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DefaultIntegral>
 
 #include <zypp/PoolItem.h>
 #include <zypp/ResPool.h>
@@ -69,35 +69,42 @@ namespace zypp
         return _status;
       }
 
+      ResStatus & statusReinit() const
+      {
+        _status.setLock( _status.isUserLockQueryMatch(), zypp::ResStatus::USER );
+        _status.resetTransact( zypp::ResStatus::USER );
+        return _status;
+      }
+
     public:
       bool isUndetermined() const
       {
-	  return status().isUndetermined();
+          return status().isUndetermined();
       }
 
       bool isRelevant() const
       {
-	  return !status().isNonRelevant();
+          return !status().isNonRelevant();
       }
 
       bool isSatisfied() const
       {
-	  return status().isSatisfied();
+          return status().isSatisfied();
       }
 
       bool isBroken() const
       {
-	  return status().isBroken();
+          return status().isBroken();
       }
 
       bool isNeeded() const
       {
-	return status().isToBeInstalled() || ( isBroken() && ! status().isLocked() );
+        return status().isToBeInstalled() || ( isBroken() && ! status().isLocked() );
       }
 
       bool isUnwanted() const
       {
-	return isBroken() && status().isLocked();
+        return isBroken() && status().isLocked();
       }
 
     private:
@@ -147,9 +154,9 @@ namespace zypp
   {
     str << obj.status();
     if (obj.resolvable())
-	str << *obj.resolvable();
+        str << *obj.resolvable();
     else
-	str << "(NULL)";
+        str << "(NULL)";
     return str;
   }
 
@@ -160,8 +167,8 @@ namespace zypp
     {
       if ( myBuddy._pimpl->_buddy )
       {
-	ERR <<  *this << " would be buddy2 in " << myBuddy << endl;
-	return;
+        ERR <<  *this << " would be buddy2 in " << myBuddy << endl;
+        return;
       }
       myBuddy._pimpl->_buddy = -resolvable()->satSolvable().id();
       _buddy = myBuddy.satSolvable().id();
@@ -203,6 +210,7 @@ namespace zypp
 
   ResStatus & PoolItem::status() const			{ return _pimpl->status(); }
   ResStatus & PoolItem::statusReset() const		{ return _pimpl->statusReset(); }
+  ResStatus & PoolItem::statusReinit() const		{ return _pimpl->statusReinit(); }
   sat::Solvable PoolItem::buddy() const			{ return _pimpl->buddy(); }
   void PoolItem::setBuddy( const sat::Solvable & solv_r )	{ _pimpl->setBuddy( solv_r ); }
   bool PoolItem::isUndetermined() const			{ return _pimpl->isUndetermined(); }
