@@ -160,6 +160,14 @@ namespace zypp
      */
     void addRepo(const std::string &repoalias);
 
+    /** Set an optional comment string describing the purpose of the query.
+     * Stored and retrieved when serializing the query. E.g. as lock.
+     */
+    void setComment(const std::string & comment) const;
+#if LEGACY(1722)
+    void setComment(const std::string & comment);
+#endif
+
     /** Installed status filter setters. */
     //@{
 
@@ -392,6 +400,8 @@ namespace zypp
 
     const StrContainer & repos() const;
 
+    const std::string & comment() const;
+
     const Edition edition() const;
     const Rel editionRel() const;
 
