@@ -25,6 +25,7 @@
 #include <zypp/base/LogTools.h>
 #include <zypp/Date.h>
 #include <zypp/KeyManager.h>
+#include <zypp/ZYppFactory.h>
 
 #include <gpgme.h>
 
@@ -46,10 +47,10 @@ namespace zypp
     {
       if ( expires_r )
       {
-	Date exp( expires_r - Date::now() );
-	int ret = exp / Date::day;
-	if ( exp < 0 ) ret -= 1;
-	return ret;
+        Date exp( expires_r - Date::now() );
+        int ret = exp / Date::day;
+        if ( exp < 0 ) ret -= 1;
+        return ret;
       }
       return INT_MAX;
     }
@@ -59,18 +60,18 @@ namespace zypp
       str::Str str;
       if ( ! expires_r )
       {
-	// translators: an annotation to a gpg keys expiry date
-	str << _("does not expire");
+        // translators: an annotation to a gpg keys expiry date
+        str << _("does not expire");
       }
       else if ( isExpired( expires_r ) )
       {
-	// translators: an annotation to a gpg keys expiry date: "expired: 1999-04-12"
-	str << ( str::Format(_("expired: %1%") ) % expires_r.printDate() );
+        // translators: an annotation to a gpg keys expiry date: "expired: 1999-04-12"
+        str << ( str::Format(_("expired: %1%") ) % expires_r.printDate() );
       }
       else
       {
-	// translators: an annotation to a gpg keys expiry date: "expires: 2111-04-12"
-	str << ( str::Format(_("expires: %1%") ) % expires_r.printDate() );
+        // translators: an annotation to a gpg keys expiry date: "expires: 2111-04-12"
+        str << ( str::Format(_("expires: %1%") ) % expires_r.printDate() );
       }
       return str;
     }
@@ -79,38 +80,45 @@ namespace zypp
     {
       if ( !expires_r )
       { // translators: an annotation to a gpg keys expiry date
-	return _("(does not expire)");
+        return _("(does not expire)");
       }
       std::string ret( expires_r.asString() );
       int ttl( hasDaysToLive( expires_r ) );
       if ( ttl <= 90 )
       {
-	ret += " ";
-	if ( ttl < 0 )
-	{ // translators: an annotation to a gpg keys expiry date
-	  ret += _("(EXPIRED)");
-	}
-	else if ( ttl == 0 )
-	{ // translators: an annotation to a gpg keys expiry date
-	  ret += _("(expires within 24h)");
-	}
-	else
-	{ // translators: an annotation to a gpg keys expiry date
-	  ret += str::form( PL_("(expires in %d day)", "(expires in %d days)", ttl ), ttl );
-	}
+        ret += " ";
+        if ( ttl < 0 )
+        { // translators: an annotation to a gpg keys expiry date
+          ret += _("(EXPIRED)");
+        }
+        else if ( ttl == 0 )
+        { // translators: an annotation to a gpg keys expiry date
+          ret += _("(expires within 24h)");
+        }
+        else
+        { // translators: an annotation to a gpg keys expiry date
+          ret += str::form( PL_("(expires in %d day)", "(expires in %d days)", ttl ), ttl );
+        }
       }
       return ret;
     }
 
-    std::string keyAlgoName( const gpgme_subkey_t & key_r )
+    inline std::string keyAlgoName( const gpgme_subkey_t & key_r )
     {
       std::string ret;
       if ( const char * n = ::gpgme_pubkey_algo_name( key_r->pubkey_algo ) )
-	ret = str::Str() << n << ' ' << key_r->length;
+        ret = str::Str() << n << ' ' << key_r->length;
       else
-	ret = "?";
+        ret = "?";
       return ret;
     }
+
+    inline bool shorterIsSuffixCI( const std::string & lhs, const std::string & rhs )
+    {
+      if ( lhs.size() >= rhs.size() )
+        return str::endsWithCI( lhs, rhs );
+      return str::endsWithCI( rhs, lhs );
+    }
   } //namespace
   ///////////////////////////////////////////////////////////////////
 
@@ -189,6 +197,101 @@ namespace zypp
     return str::Str() << id() << " " << created().printDate() << " [" << expiresDetail( expires() ) << "]";
   }
 
+  ///////////////////////////////////////////////////////////////////
+  /// \class PublicKeySignatureData::Impl
+  /// \brief  PublicKeySignatureData implementation.
+  ///////////////////////////////////////////////////////////////////
+
+  struct PublicKeySignatureData::Impl
+  {
+    std::string _keyid;
+    std::string _name;
+    Date        _created;
+    Date        _expires;
+
+  public:
+    /** Offer default Impl. */
+    static shared_ptr<Impl> nullimpl();
+
+  private:
+    friend Impl * rwcowClone<Impl>( const Impl * rhs );
+    /** clone for RWCOW_pointer */
+    Impl * clone() const;
+  };
+
+  shared_ptr<zypp::PublicKeySignatureData::Impl> PublicKeySignatureData::Impl::nullimpl()
+  {
+    static shared_ptr<Impl> _nullimpl( new Impl );
+    return _nullimpl;
+  }
+
+  zypp::PublicKeySignatureData::Impl *PublicKeySignatureData::Impl::clone() const
+  {
+    return new Impl( *this );
+  }
+
+  ///////////////////////////////////////////////////////////////////
+  /// class PublicKeySignatureData
+  ///////////////////////////////////////////////////////////////////
+
+  PublicKeySignatureData::PublicKeySignatureData()
+    : _pimpl( Impl::nullimpl() )
+  {}
+
+  PublicKeySignatureData::PublicKeySignatureData(const _gpgme_key_sig *rawKeySignatureData)
+    : _pimpl (new Impl)
+  {
+    _pimpl->_keyid = str::asString(rawKeySignatureData->keyid);
+    _pimpl->_name = str::asString(rawKeySignatureData->uid);
+    _pimpl->_created = zypp::Date(rawKeySignatureData->timestamp);
+    _pimpl->_expires = zypp::Date(rawKeySignatureData->expires);
+  }
+
+  PublicKeySignatureData::~PublicKeySignatureData()
+  {}
+
+  PublicKeySignatureData::operator bool() const
+  { return !_pimpl->_keyid.empty(); }
+
+  std::string PublicKeySignatureData::id() const
+  { return _pimpl->_keyid; }
+
+  std::string PublicKeySignatureData::name() const
+  { return _pimpl->_name; }
+
+  Date PublicKeySignatureData::created() const
+  { return _pimpl->_created; }
+
+  Date PublicKeySignatureData::expires() const
+  { return _pimpl->_expires; }
+
+  bool PublicKeySignatureData::expired() const
+  { return isExpired( _pimpl->_expires ); }
+
+  int PublicKeySignatureData::daysToLive() const
+  { return hasDaysToLive( _pimpl->_expires ); }
+
+  std::string PublicKeySignatureData::asString() const
+  {
+    std::string nameStr;
+    if (!name().empty()) {
+      nameStr = str::Str() << name() << " ";
+    }
+    else {
+      nameStr = "[User ID not found] ";
+    }
+    return str::Str() << nameStr
+                      << id() << " "
+                      << created().printDate()
+                      << " [" << expiresDetail( expires() ) << "]";
+  }
+
+  bool PublicKeySignatureData::inTrustedRing() const
+  { return getZYpp()->keyRing()->isKeyTrusted(id()); }
+
+  bool PublicKeySignatureData::inKnownRing() const
+  { return getZYpp()->keyRing()->isKeyKnown(id()); }
+
   ///////////////////////////////////////////////////////////////////
   /// \class PublicKeyData::Impl
   /// \brief  PublicKeyData implementation.
@@ -204,6 +307,7 @@ namespace zypp
     Date        _expires;
 
     std::vector<PublicSubkeyData> _subkeys;
+    std::vector<PublicKeySignatureData> _signatures;
 
   public:
     bool hasSubkeyId( const std::string & id_r ) const;
@@ -219,13 +323,11 @@ namespace zypp
     Impl * clone() const;
   };
 
-  bool PublicKeyData::Impl::hasSubkeyId(const std::string &id_r) const
+  bool PublicKeyData::Impl::hasSubkeyId( const std::string &id_r) const
   {
     bool ret = false;
-    for ( const PublicSubkeyData & sub : _subkeys )
-    {
-      if ( sub.id() == id_r )
-      {
+    for ( const PublicSubkeyData & sub : _subkeys ) {
+      if ( shorterIsSuffixCI( sub.id(), id_r ) ) {
         ret = true;
         break;
       }
@@ -241,7 +343,7 @@ namespace zypp
 
   shared_ptr<PublicKeyData::Impl> PublicKeyData::Impl::fromGpgmeKey(gpgme_key_t rawData)
   {
-    //gpgpme stores almost nothing in the top level key
+    //gpgme stores almost nothing in the top level key
     //the information we look for is stored in the subkey, where subkey[0]
     //is always the primary key
     gpgme_subkey_t sKey = rawData->subkeys;
@@ -250,13 +352,17 @@ namespace zypp
       //libzypp expects the date of the latest signature on the first uid
       if ( rawData->uids && rawData->uids->signatures ) {
         data->_created = zypp::Date(rawData->uids->signatures->timestamp);
-	// bsc#1179222: The keyring does not order the signatures when multiple
-	// versions of the same key are imported. We take the last signature here,
-	// the one GPGME_EXPORT_MODE_MINIMAL will later use in export.
-	for ( auto t = rawData->uids->signatures->next; t; t = t->next ) {
-	  if ( t->timestamp > data->_created )
-	    data->_created = t->timestamp;
-	}
+        // bsc#1179222: The keyring does not order the signatures when multiple
+        // versions of the same key are imported. We take the last signature here,
+        // the one GPGME_EXPORT_MODE_MINIMAL will later use in export.
+        for ( auto t = rawData->uids->signatures->next; t; t = t->next ) {
+            if (t->keyid != nullptr) {
+              data->_signatures.push_back(PublicKeySignatureData(t));
+            }
+
+          if ( t->timestamp > data->_created )
+            data->_created = t->timestamp;
+        }
       }
       else
         data->_created = zypp::Date(sKey->timestamp);
@@ -346,6 +452,9 @@ namespace zypp
 
   std::string PublicKeyData::asString() const
   {
+    if ( not *this )
+      return "[NO_KEY]";
+
     str::Str str;
     str << "[" << _pimpl->_id << "-" << gpgPubkeyRelease();
     for ( auto && sub : _pimpl->_subkeys )
@@ -359,11 +468,18 @@ namespace zypp
   Iterable<PublicKeyData::SubkeyIterator> PublicKeyData::subkeys() const
   { return makeIterable( &(*_pimpl->_subkeys.begin()), &(*_pimpl->_subkeys.end()) ); }
 
+  Iterable<PublicKeyData::KeySignatureIterator> PublicKeyData::signatures() const
+  { return makeIterable( &(*_pimpl->_signatures.begin()), &(*_pimpl->_signatures.end()) ); }
+
   bool PublicKeyData::providesKey( const std::string & id_r ) const
   {
-    if ( id_r.size() == 8 )	// as a convenience allow to test the 8byte short ID rpm uses as gpg-pubkey version
-      return str::endsWithCI( _pimpl->_id, id_r );
-    return( id_r == _pimpl->_id || _pimpl->hasSubkeyId( id_r ) );
+    if ( not isSafeKeyId( id_r ) )
+      return( id_r.size() == 8 && str::endsWithCI( _pimpl->_id, id_r ) );
+
+    if ( str::endsWithCI( _pimpl->_fingerprint, id_r ) )
+      return true;
+
+    return _pimpl->hasSubkeyId( id_r );
   }
 
   PublicKeyData::AsciiArt PublicKeyData::asciiArt() const
@@ -407,7 +523,7 @@ namespace zypp
         ZYPP_THROW(Exception("Can't read public key from " + keyFile_r.asString() + ", file not found"));
 
       if ( filesystem::hardlinkCopy( keyFile_r, path() ) != 0 )
-	ZYPP_THROW(Exception("Can't copy public key data from " + keyFile_r.asString() + " to " +  path().asString() ));
+        ZYPP_THROW(Exception("Can't copy public key data from " + keyFile_r.asString() + " to " +  path().asString() ));
 
       readFromFile();
     }
@@ -423,8 +539,8 @@ namespace zypp
     {
       if ( ! keyData_r )
       {
-	WAR << "Invalid PublicKeyData supplied: scanning from file" << endl;
-	readFromFile();
+        WAR << "Invalid PublicKeyData supplied: scanning from file" << endl;
+        readFromFile();
       }
     }
 
@@ -520,6 +636,9 @@ namespace zypp
   PublicKey::~PublicKey()
   {}
 
+  PublicKey PublicKey::noThrow( const Pathname & keyFile_r )
+  try { return PublicKey( keyFile_r ); } catch(...) { return PublicKey(); }
+
   const PublicKeyData & PublicKey::keyData() const
   { return _pimpl->keyData(); }
 
@@ -529,6 +648,17 @@ namespace zypp
   const std::list<PublicKeyData> & PublicKey::hiddenKeys() const
   { return _pimpl->hiddenKeys(); }
 
+  bool PublicKey::fileProvidesKey( const std::string & id_r ) const
+  {
+    if ( providesKey( id_r ) )
+      return true;
+    for ( const auto & keydata : hiddenKeys() ) {
+      if ( keydata.providesKey( id_r ) )
+        return true;
+    }
+    return false;
+  }
+
   std::string PublicKey::id() const
   { return keyData().id(); }
 
@@ -572,7 +702,7 @@ namespace zypp
   { return rhs.keyData() == keyData(); }
 
   bool PublicKey::operator==( const std::string & sid ) const
-  { return sid == id(); }
+  { return ( isSafeKeyId( sid ) || sid.size() == 8 ) && str::endsWithCI( fingerprint(), sid ); }
 
   std::ostream & dumpOn( std::ostream & str, const PublicKey & obj )
   { return dumpOn( str, obj.keyData() ); }
