@@ -85,7 +85,7 @@ namespace zypp
        */
       static unsigned defaultPriority();
       /**
-       * The least priority (<tt>unsigned(-1)</tt>). 
+       * The least priority (<tt>unsigned(-1)</tt>).
        */
       static unsigned noPriority();
       /**
@@ -302,13 +302,13 @@ namespace zypp
        *   \c repo_gpgcheck = \c on same as the default.
        *
        *   \c repo_gpgcheck = \c off will silently accept unsigned repos. It will NOT turn of
-       *   signature checking on the whole, nevertheless it's not a secure setting.
+       *   signature checking on the whole. Nevertheless, it's not a secure setting.
        *
        *   \c pkg_gpgcheck = \c on will enforce the package signature checking and the need
        *   to confirm unsigned packages for all repos (signed and unsigned).
        *
        *   \c pkg_gpgcheck = \c off will silently accept unsigned packages. It will NOT turn of
-       *   signature checking on the whole, nevertheless it's not a secure setting.
+       *   signature checking on the whole. Nevertheless, it's not a secure setting.
        *
        * If \c gpgCheck is \c off (not recommneded), no checks are performed. You can still
        * enable them individually by setting \c repo_gpgcheck and/or \c pkg_gpgcheck to \c on.
@@ -366,14 +366,14 @@ namespace zypp
 
       /** Some predefined settings */
       enum class GpgCheck {
-	indeterminate,		//< not specified
-	On,			//< 1** --gpgcheck
-	Strict,			//< 111 --gpgcheck-strict
-	AllowUnsigned,		//< 100 --gpgcheck-allow-unsigned
-	AllowUnsignedRepo,	//< 10* --gpgcheck-allow-unsigned-repo
-	AllowUnsignedPackage,	//< 1*0 --gpgcheck-allow-unsigned-package
-	Default,		//< *** --default-gpgcheck
-	Off,			//< 0** --no-gpgcheck
+        indeterminate,		//< not specified
+        On,			//< 1** --gpgcheck
+        Strict,			//< 111 --gpgcheck-strict
+        AllowUnsigned,		//< 100 --gpgcheck-allow-unsigned
+        AllowUnsignedRepo,	//< 10* --gpgcheck-allow-unsigned-repo
+        AllowUnsignedPackage,	//< 1*0 --gpgcheck-allow-unsigned-package
+        Default,		//< *** --default-gpgcheck
+        Off,			//< 0** --no-gpgcheck
       };
 
       /** Adjust *GpgCheck settings according to \a mode_r.
@@ -521,6 +521,12 @@ namespace zypp
       LocaleSet getLicenseLocales( const std::string & name_r ) const;
      //@}
 
+      /**
+       * Returns true if this repository requires the media.1/media file to be included
+       * in the metadata status and repo status calculations.
+       */
+      bool requireStatusWithMediaFile () const;
+
     public:
       /**
        * Write a human-readable representation of this RepoInfo object
