@@ -12,8 +12,6 @@
 #ifndef ZYPP_RESFILTERS_H
 #define ZYPP_RESFILTERS_H
 
-#include <boost/function.hpp>
-
 #include <zypp/base/Functional.h>
 #include <zypp/Filter.h>
 #include <zypp/Resolvable.h>
@@ -60,7 +58,7 @@ namespace zypp
      *     return true;
      *   }
      *
-     *   unsigned _counter;
+     *   unsigned & _counter;
      * };
      *
      * ResStore store;
@@ -106,11 +104,6 @@ namespace zypp
      * \note These functors are not limited to be used with ResStore::forEach.
      * You can use them with std::algorithms as well.
      *
-     * \note In case you already have functions or methods which do what you
-     * want, but thet don't perfectly match the required signature: Make yourself
-     * familiar with <tt>std::ptr_fun, mem_fun, bind1st, bind2nd and compose</tt>.
-     * They are sometimes quite helpfull.
-     *
      * \c PrintAndCount is an example how a functor can return data collected
      * during the query. You ca easily write a collector, that takes a
      * <tt>std:list\<ResObject::Ptr\>\&</tt> and fills it with the matches
@@ -118,7 +111,7 @@ namespace zypp
      *
      * But as a rule of thumb, a functor should be lightweight. If you
      * want to get data out, pass references to variables in (and assert
-     * these variables live as long as the query lasts). Or use \ref FunctorRef.
+     * these variables live as long as the query lasts). Or use std::ref.
      *
      * Internally all functors are passed by value. Thus it would not help
      * you to create an instance of some collecting functor, and pass it
@@ -135,7 +128,7 @@ namespace zypp
      * up and down.
      *
      * If you look at a functor, you'll see that it contains both, the function
-     * to call (it's <tt>operator()</tt> ) and the data you'd otherwise pass as
+     * to call (its <tt>operator()</tt>) and the data you'd otherwise pass as
      * <tt>void * data</tt>. That's nice and safe.
      *
      * \todo migrate to namespace filter and enhance to support Solvables as well.
@@ -147,17 +140,13 @@ namespace zypp
     //
     ///////////////////////////////////////////////////////////////////
 
-    /** */
-    typedef std::unary_function<ResObject::constPtr, bool> ResObjectFilterFunctor;
-    typedef boost::function<bool ( ResObject::constPtr )> ResFilter;
-
     /** */
     template<class TRes>
       inline filter::ByKind byKind()
       { return filter::ByKind( ResTraits<TRes>::kind ); }
 
     /** Select ResObject by name. */
-    struct ByName : public ResObjectFilterFunctor
+    struct ByName
     {
       ByName()
       {}
@@ -175,7 +164,7 @@ namespace zypp
     };
 
     /** Select ResObject by repository or repository alias. */
-    struct ByRepository : public ResObjectFilterFunctor
+    struct ByRepository
     {
       ByRepository( Repository repository_r )
       : _alias( repository_r.info().alias() )
@@ -206,7 +195,7 @@ namespace zypp
      * \endcode
     */
     template<class TCompare = CompareByEQ<Edition> >
-      struct ByEdition : public ResObjectFilterFunctor
+      struct ByEdition
       {
         ByEdition( const Edition & edition_r, TCompare cmp_r )
         : _edition( edition_r )
@@ -246,7 +235,7 @@ namespace zypp
      * \endcode
     */
     template<class TCompare = CompareByEQ<Arch> >
-      struct ByArch : public ResObjectFilterFunctor
+      struct ByArch
       {
         ByArch( const Arch & arch_r, TCompare cmp_r )
         : _arch( arch_r )
@@ -281,69 +270,66 @@ namespace zypp
     //
     ///////////////////////////////////////////////////////////////////
 
-    /** */
-    typedef std::unary_function<PoolItem, bool> PoolItemFilterFunctor;
-
     /** Select PoolItem by installed. */
-    struct ByInstalled : public PoolItemFilterFunctor
+    struct ByInstalled
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().isInstalled();
+        return p.status().isInstalled();
       }
     };
 
     /** Select PoolItem by uninstalled. */
-    struct ByUninstalled : public PoolItemFilterFunctor
+    struct ByUninstalled
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().isUninstalled();
+        return p.status().isUninstalled();
       }
     };
 
     /** Select PoolItem by transact. */
-    struct ByTransact : public PoolItemFilterFunctor
+    struct ByTransact
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().transacts();
+        return p.status().transacts();
       }
     };
 
     /** Select PoolItem by lock. */
-    struct ByLock : public PoolItemFilterFunctor
+    struct ByLock
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().isLocked();
+        return p.status().isLocked();
       }
     };
 
     /** Select PoolItem by keep. */
-    struct ByKeep : public PoolItemFilterFunctor
+    struct ByKeep
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().isKept();
+        return p.status().isKept();
       }
     };
 
     /** PoolItem which is recommended. */
-    struct ByRecommended : public PoolItemFilterFunctor
+    struct ByRecommended
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().isRecommended();
+        return p.status().isRecommended();
       }
     };
 
     /** PoolItem which is suggested. */
-    struct BySuggested : public PoolItemFilterFunctor
+    struct BySuggested
     {
       bool operator()( const PoolItem & p ) const
       {
-	return p.status().isSuggested();
+        return p.status().isSuggested();
       }
     };
 
