@@ -33,6 +33,8 @@
 namespace zypp
 { /////////////////////////////////////////////////////////////////
 
+  class RepoManager;
+
   ///////////////////////////////////////////////////////////////////
   //
   //	CLASS NAME : ZConfig
@@ -43,6 +45,8 @@ namespace zypp
    *
    * It reads /etc/zypp/zypp.conf, the filename can be overridden by
    * setting the ZYPP_CONF environment variable to a different file.
+   * Config values for \ref MediaConfig are forwarded to the MediaConfig
+   * singleton.
    *
    * Note, if you add settings to this file, please follow the following
    * convention:
@@ -183,6 +187,7 @@ namespace zypp
       */
       Pathname repoPackagesPath() const;
 
+
       /**
        * Set a new \a path as the default repo cache path
        */
@@ -218,6 +223,28 @@ namespace zypp
        */
       Pathname needrebootPath() const;
 
+      /**
+       * Enables or disables the use of the geoip feature of download.opensuse.org
+       */
+      void setGeoipEnabled( bool enable = true );
+
+      /**
+       * Returns true if zypp should use the geoip feature of download.opensuse.org
+       */
+      bool geoipEnabled () const;
+
+      /**
+       * Path where the geoip caches are kept (/var/cache/zypp/geoip)
+       */
+      Pathname geoipCachePath() const;
+
+      /**
+       * All hostnames we want to rewrite using the geoip feature. The \ref RepoManager
+       * will try to query each hostname via: https://hostname/geoip to receive a redirection
+       * target for requests to the given hostname. The geoip targets are cached in \ref geoipCachePath.
+       */
+      const std::vector<std::string> geoipHostnames () const;
+
       /**
        * Path containing custom repo variable definitions (configPath()/vars.d).
        * \see \ref zypp::repo::RepoVarExpand Repo variable expander
@@ -329,9 +356,9 @@ namespace zypp
       DownloadMode commit_downloadMode() const;
 
       /** \name Signature checking (repodata and packages)
-       * If \ref gpgcheck is \c on (the default) we will either check the signature
+       * If \ref gpgcheck is \c on (the default), we will either check the signature
        * of repo metadata (packages are secured via checksum in the metadata), or the
-       * signature of an rpm package to install if it's repo metadata are not signed
+       * signature of an rpm package to install if its repo metadata is not signed
        * or not checked. If \ref gpgcheck is \c off, no checks are performed.
        *
        * The default behavior can be altered by explicitly setting \ref repo_gpgcheck and/or
@@ -361,7 +388,7 @@ namespace zypp
       Pathname vendorPath() const;
 
       /**
-       * The resolvers general attitude when resolving jobs.
+       * The resolver's general attitude when resolving jobs.
        */
       ResolverFocus solver_focus() const;
 
@@ -540,10 +567,24 @@ namespace zypp
       std::string multiversionKernels() const;
 
       //@}
+
     public:
       class Impl;
       /** Dtor */
       ~ZConfig();
+      void notifyTargetChanged();  ///< internal
+
+  private:
+      friend class RepoManager;
+      /** The builtin config file value. */
+      Pathname builtinRepoCachePath() const;
+      /** The builtin config file value. */
+      Pathname builtinRepoMetadataPath() const;
+      /** The builtin config file value. */
+      Pathname builtinRepoSolvfilesPath() const;
+      /** The builtin config file value. */
+      Pathname builtinRepoPackagesPath() const;
+
   private:
       friend class Impl;
       /** Default ctor. */
