@@ -18,7 +18,7 @@
 
 #include <zypp/PoolItem.h>
 #include <zypp/sat/Transaction.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DefaultIntegral>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -87,6 +87,14 @@ namespace zypp
       /** Set \ref attemptToModify */
       void attemptToModify( bool yesno_r );
 
+      /**
+       * \c True if the commit was executed in one big rpm transaction. This can be used to figure out
+       *    when it is required to show more information about which packages failed during the transaction,
+       *    because otherwise, that information might get lost in the backlog.
+       */
+      bool singleTransactionMode() const;
+      void setSingleTransactionMode( bool yesno_r );
+
       /** The full transaction list.
        * The complete list including transaction steps that do not require
        * any action (like obsoletes or non-package actions). Depending on
@@ -164,13 +172,13 @@ namespace zypp
        * \see \ref Transaction, \ref transaction()
        */
       //@{
-	/** Whether all steps were performed successfully (none skipped or error) */
-	bool allDone() const
-	{ return transaction().actionEmpty( ~sat::Transaction::STEP_DONE ); }
+        /** Whether all steps were performed successfully (none skipped or error) */
+        bool allDone() const
+        { return transaction().actionEmpty( ~sat::Transaction::STEP_DONE ); }
 
-	/** Whether an error ocurred (skipped streps are ok). */
-	bool noError() const
-	{ return transaction().actionEmpty( sat::Transaction::STEP_ERROR ); }
+        /** Whether an error ocurred (skipped streps are ok). */
+        bool noError() const
+        { return transaction().actionEmpty( sat::Transaction::STEP_ERROR ); }
       //@}
 
     public:
