@@ -21,7 +21,7 @@
 #include <zypp/base/Logger.h>
 #include <zypp/base/String.h>
 #include <zypp/ExternalProgram.h>
-#include <zypp/base/ProvideNumericId.h>
+#include <zypp-core/base/ProvideNumericId>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -126,7 +126,7 @@ namespace zypp
 
         TraceCAD( TraceCAD && rhs )
         { ++_totalTraceCAD();
-	  traceCAD( MOVECTOR, *this, rhs ); }
+          traceCAD( MOVECTOR, *this, rhs ); }
 
         TraceCAD & operator=( const TraceCAD & rhs )
         { traceCAD( ASSIGN, *this, rhs ); return *this; }
