@@ -32,10 +32,10 @@ namespace zypp {
 
       protected:
 
-	virtual void attachTo (bool next = false) override;
+        virtual void attachTo (bool next = false) override;
         virtual void releaseFrom( const std::string & ejectDev ) override;
-	virtual void getFile(const Pathname & filename, const ByteCount &expectedFileSize_r ) const override;
-	virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
+        virtual void getFile( const OnMediaLocation & file ) const override;
+        virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
         virtual void getDirInfo( std::list<std::string> & retlist,
                                  const Pathname & dirname, bool dots = true ) const override;
         virtual void getDirInfo( filesystem::DirContent & retlist,
@@ -45,7 +45,7 @@ namespace zypp {
       public:
 
         MediaDISK( const Url &      url_r,
-		   const Pathname & attach_point_hint_r );
+                   const Pathname & attach_point_hint_r );
 
         virtual ~MediaDISK() override { try { release(); } catch(...) {} }
 
