@@ -12,7 +12,7 @@
 #include <iostream>
 
 #include <zypp/base/Logger.h>
-#include <zypp/media/Mount.h>
+#include <zypp-media/Mount>
 
 #include <zypp/media/MediaISO.h>
 
@@ -61,31 +61,25 @@ namespace zypp
       if( _filesystem.empty())
         _filesystem = "auto";
 
-      std::string arg;
-      zypp::Url   src;
-      try
+      Url src;
       {
-        // this percent-decodes the query parameter, it must be later encoded
-        // again before used in a Url object
-        arg = _url.getQueryParam("url");
-        if( arg.empty() && _isofile.dirname().absolute())
-        {
-          src = std::string("dir:///");
-          src.setPathName(url::encode(_isofile.dirname().asString(), URL_SAFE_CHARS));
+        const std::string & arg { _url.getQueryParam("url") };
+        if ( arg.empty() ) {
+          src = "dir:/";
+          src.setPathName( _isofile.dirname() );
           _isofile = _isofile.basename();
         }
-        else
+        else try {
+          src = arg;
+        }
+        catch( const url::UrlException & e )
         {
-          src = url::encode(arg, URL_SAFE_CHARS);
+          ZYPP_CAUGHT(e);
+          ERR << "Unable to parse iso filename source media url" << std::endl;
+          MediaBadUrlException ne(_url);
+          ne.remember(e);
+          ZYPP_THROW(ne);
         }
-      }
-      catch(const zypp::url::UrlException &e)
-      {
-        ZYPP_CAUGHT(e);
-        ERR << "Unable to parse iso filename source media url" << std::endl;
-	MediaBadUrlException ne(_url);
-	ne.remember(e);
-	ZYPP_THROW(ne);
       }
       if( !src.isValid())
       {
@@ -155,7 +149,7 @@ namespace zypp
 
       try
       {
-        manager.provideFile(_parentId, _isofile);
+        manager.provideFile(_parentId, OnMediaLocation(_isofile) );
       }
       catch(const MediaException &e1)
       {
@@ -169,12 +163,12 @@ namespace zypp
           ZYPP_CAUGHT(e2);
         }
 
-	MediaMountException e3(
+        MediaMountException e3(
           "Unable to find iso filename on source media",
           _url.asString(), attachPoint().asString()
         );
-	e3.remember(e1);
-	ZYPP_THROW(e3);
+        e3.remember(e1);
+        ZYPP_THROW(e3);
       }
 
       // if the provided file is a symlink, expand it (#274651)
@@ -205,7 +199,7 @@ namespace zypp
 
       if( !isUseableAttachPoint( attachPoint() ) )
       {
-	setAttachPoint( createAttachPoint(), true );
+        setAttachPoint( createAttachPoint(), true );
       }
       std::string mountpoint( attachPoint().asString() );
       std::string mountopts("ro,loop");
@@ -272,9 +266,9 @@ namespace zypp
     }
 
     // ---------------------------------------------------------------
-    void MediaISO::getFile(const Pathname &filename, const ByteCount &expectedFileSize_r) const
+    void MediaISO::getFile( const OnMediaLocation &file ) const
     {
-      MediaHandler::getFile(filename, expectedFileSize_r);
+      MediaHandler::getFile(file);
     }
 
     // ---------------------------------------------------------------
