@@ -23,13 +23,14 @@
 #include <algorithm>
 
 
+#include <zypp/ManagedFile.h>
 #include <zypp/ZConfig.h>
 #include <zypp/base/Logger.h>
 #include <zypp/media/MediaMultiCurl.h>
+#include <zypp/zypp_detail/ZYppImpl.h>
 #include <zypp-core/zyppng/base/private/linuxhelpers_p.h>
 #include <zypp-curl/parser/MetaLinkParser>
 #include <zypp-curl/parser/zsyncparser.h>
-#include <zypp/ManagedFile.h>
 #include <zypp-curl/private/curlhelper_p.h>
 #include <zypp-curl/auth/CurlAuthData>
 #include <zypp-curl/parser/metadatahelper.h>
@@ -223,7 +224,7 @@ private:
   int _dnspipe = -1;
 };
 
-class multifetchrequest {
+class multifetchrequest : protected internal::CurlPollHelper::CurlPoll  {
 public:
   multifetchrequest(const MediaMultiCurl *context, const Pathname &filename, const Url &baseurl, CURLM *multi, FILE *fp, callback::SendReport<DownloadProgressReport> *report, MediaBlockList &&blklist, off_t filesize);
   ~multifetchrequest();
@@ -250,8 +251,6 @@ protected:
 
   off_t _filesize = 0; //< size of the file we want to download
 
-  CURLM *_multi = nullptr;
-
   std::list< std::unique_ptr<multifetchworker> > _workers;
   bool _stealing = false;
   bool _havenewjob = false;
@@ -951,14 +950,14 @@ multifetchworker::run()
 
 
 multifetchrequest::multifetchrequest(const MediaMultiCurl *context, const Pathname &filename, const Url &baseurl, CURLM *multi, FILE *fp, callback::SendReport<DownloadProgressReport> *report, MediaBlockList &&blklist, off_t filesize)
-  : _context(context)
+  : internal::CurlPollHelper::CurlPoll{ multi }
+  , _context(context)
   , _filename(filename)
   , _baseurl(baseurl)
   , _fp(fp)
   , _report(report)
   , _blklist(std::move(blklist))
   , _filesize(filesize)
-  , _multi(multi)
   , _starttime(currentTime())
   , _timeout(context->_settings.timeout())
   , _connect_timeout(context->_settings.connectTimeout())
@@ -1007,74 +1006,10 @@ multifetchrequest::run(std::vector<Url> &urllist)
   int workerno = 0;
   std::vector<Url>::iterator urliter = urllist.begin();
 
-  struct CurlMuliSockHelper {
-    CurlMuliSockHelper( multifetchrequest &p ) : _parent(p) {
-      curl_multi_setopt( _parent._multi, CURLMOPT_SOCKETFUNCTION, socketcb );
-      curl_multi_setopt( _parent._multi, CURLMOPT_SOCKETDATA, this );
-      curl_multi_setopt( _parent._multi, CURLMOPT_TIMERFUNCTION, timercb );
-      curl_multi_setopt( _parent._multi, CURLMOPT_TIMERDATA, this );
-    }
-
-    ~CurlMuliSockHelper() {
-      curl_multi_setopt( _parent._multi, CURLMOPT_SOCKETFUNCTION, nullptr );
-      curl_multi_setopt( _parent._multi, CURLMOPT_SOCKETDATA, nullptr );
-      curl_multi_setopt( _parent._multi, CURLMOPT_TIMERFUNCTION, nullptr );
-      curl_multi_setopt( _parent._multi, CURLMOPT_TIMERDATA, nullptr );
-    }
-
-    static int socketcb (CURL * easy, curl_socket_t s, int what, CurlMuliSockHelper *userp, void *sockp ) {
-      auto it = std::find_if( userp->socks.begin(), userp->socks.end(), [&]( const GPollFD &fd){ return fd.fd == s; });
-      gushort events = 0;
-      if ( what == CURL_POLL_REMOVE ) {
-        if ( it == userp->socks.end() ) {
-          WAR << "Ignoring unknown socket in static_socketcb" << std::endl;
-          return 0;
-        }
-        userp->socks.erase(it);
-        return 0;
-      } else if ( what == CURL_POLL_IN ) {
-        events = G_IO_IN | G_IO_HUP | G_IO_ERR;
-      } else if ( what == CURL_POLL_OUT ) {
-        events = G_IO_OUT | G_IO_ERR;
-      } else if ( what == CURL_POLL_INOUT ) {
-        events = G_IO_IN | G_IO_OUT | G_IO_HUP | G_IO_ERR;
-      }
-
-      if ( it != userp->socks.end() ) {
-        it->events = events;
-        it->revents = 0;
-      } else {
-        userp->socks.push_back(
-          GPollFD{
-            .fd = s,
-            .events = events,
-            .revents = 0
-          }
-        );
-      }
-
-      return 0;
-    }
-
-    //called by curl to setup a timer
-    static int timercb( CURLM *, long timeout_ms, CurlMuliSockHelper *thatPtr ) {
-      if ( !thatPtr )
-        return 0;
-      if ( timeout_ms == -1 )
-        thatPtr->timeout_ms.reset(); // curl wants to delete its timer
-      else
-        thatPtr->timeout_ms = timeout_ms; // maximum time curl wants us to sleep
-      return 0;
-    }
-
-    multifetchrequest &_parent;
-    std::vector<GPollFD> socks;
-    std::optional<long> timeout_ms = 0; //if set curl wants a timeout
-  } _curlHelper(*this) ;
+  internal::CurlPollHelper _curlHelper(*this);
 
   // kickstart curl
-  int handles = 0;
-  CURLMcode mcode = curl_multi_socket_action( _multi, CURL_SOCKET_TIMEOUT, 0, &handles );
+  CURLMcode mcode = _curlHelper.handleTimout();
   if (mcode != CURLM_OK)
     ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
 
@@ -1153,9 +1088,9 @@ multifetchrequest::run(std::vector<Url> &urllist)
       dnsFdCount = waitFds.size(); // remember how many dns fd's we have
       waitFds.insert( waitFds.end(), _curlHelper.socks.begin(), _curlHelper.socks.end() ); // add the curl fd's to the poll data
 
-      int r = zyppng::eintrSafeCall( g_poll, waitFds.data(), waitFds.size(), timeoutMs );
+      int r = zypp_detail::zypp_poll( waitFds, timeoutMs );
       if ( r == -1 )
-        ZYPP_THROW(MediaCurlException(_baseurl, "g_poll() failed", "unknown error"));
+        ZYPP_THROW(MediaCurlException(_baseurl, "zypp_poll() failed", "unknown error"));
       if ( r != 0 && _lookupworkers ) {
         for (auto workeriter = _workers.begin(); workeriter != _workers.end(); ++workeriter)
           {
@@ -1171,33 +1106,13 @@ multifetchrequest::run(std::vector<Url> &urllist)
 
       // run curl
       if ( r == 0 ) {
-        int handles = 0;
-        CURLMcode mcode = curl_multi_socket_action( _multi, CURL_SOCKET_TIMEOUT, 0, &handles );
+        CURLMcode mcode = _curlHelper.handleTimout();
         if (mcode != CURLM_OK)
           ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
       } else {
-        for ( int sock = dnsFdCount; sock < waitFds.size(); sock++ ) {
-          const auto &waitFd = waitFds[sock];
-          if ( waitFd.revents == 0 )
-            continue;
-
-          int ev = 0;
-          if ( (waitFd.revents & G_IO_HUP) == G_IO_HUP
-              || (waitFd.revents & G_IO_IN) == G_IO_IN ) {
-            ev = CURL_CSELECT_IN;
-          }
-          if ( (waitFd.revents & G_IO_OUT) == G_IO_OUT ) {
-            ev |= CURL_CSELECT_OUT;
-          }
-          if ( (waitFd.revents & G_IO_ERR) == G_IO_ERR ) {
-            ev |= CURL_CSELECT_ERR;
-          }
-
-          int runn = 0;
-          CURLMcode mcode = curl_multi_socket_action( _multi, waitFd.fd, ev, &runn );
-          if (mcode != CURLM_OK)
-            ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
-        }
+        CURLMcode mcode = _curlHelper.handleSocketActions( waitFds, dnsFdCount );
+        if (mcode != CURLM_OK)
+          ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
       }
 
       double now = currentTime();
