@@ -37,11 +37,11 @@ namespace zypp {
 
       protected:
 
-	virtual void attachTo (bool next = false) override;
+        virtual void attachTo (bool next = false) override;
 
         virtual void releaseFrom( const std::string & ejectDev ) override;
-	virtual void getFile( const Pathname & filename, const ByteCount &expectedFileSize_r ) const override;
-	virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
+        virtual void getFile( const OnMediaLocation & file ) const override;
+        virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
         virtual void getDirInfo( std::list<std::string> & retlist,
                                  const Pathname & dirname, bool dots = true ) const override;
         virtual void getDirInfo( filesystem::DirContent & retlist,
@@ -51,11 +51,11 @@ namespace zypp {
       public:
 
         MediaNFS( const Url&       url_r,
-		  const Pathname & attach_point_hint_r );
+                  const Pathname & attach_point_hint_r );
 
         virtual ~MediaNFS() override { try { release(); } catch(...) {} }
 
-    	virtual bool isAttached() const override;
+        virtual bool isAttached() const override;
     };
 
     ///////////////////////////////////////////////////////////////////
