@@ -16,7 +16,7 @@
 
 #include <zypp/base/PtrTypes.h>
 #include <zypp/base/Function.h>
-#include <zypp/base/InputStream.h>
+#include <zypp-core/base/InputStream>
 
 #include <zypp/Pathname.h>
 #include <zypp/IdString.h>
@@ -54,8 +54,8 @@ namespace zypp
         Edition     edition() const;
         Arch        arch()    const;
 
-	std::string shortName()	const;
-	std::string summary()	const;
+        std::string shortName()	const;
+        std::string summary()	const;
 
       public:
         std::string productline()     const;
