@@ -16,8 +16,8 @@
 
 #include <zypp/base/Logger.h>
 #include <zypp/base/String.h>
-#include <zypp/base/DtorReset.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DtorReset>
+#include <zypp-core/base/DefaultIntegral>
 
 #include <zypp/parser/xml/ParseDef.h>
 #include <zypp/parser/xml/ParseDefException.h>
@@ -210,7 +210,7 @@ namespace zypp
         {
           if ( reader_r->depth() == 0 )
           {
-            // on the verry first level we skip any initial whitespace and comments...
+            // on the very first level we skip any initial whitespace and comments...
             do {
               // advance to next node
               if ( ! reader_r.nextNode() )
