@@ -50,48 +50,30 @@ namespace zypp
 
 
       std::list<std::string> structuredErrors;
-      void structuredErrorFunc( void * userData, xmlErrorPtr error )
+#if LIBXML_VERSION >= 21200
+      void structuredErrorFunc( void * userData, const xmlError * error )
+#else
+      void structuredErrorFunc( void * userData, xmlError * error )
+#endif
       {
-	if ( error )
-	{
-	  // error->message is NL terminated
-	  std::string err( str::form( "%s[%d] %s", Pathname::basename(error->file).c_str(), error->line,
-				      str::stripSuffix( error->message, "\n" ).c_str() ) );
-	  structuredErrors.push_back( err );
-	  WAR << err << endl;
-	}
-#if 0
         if ( error )
         {
-#define X(m) SEC << " " << #m << "\t" << error->m << endl
-#define XS(m) SEC << " " << #m << "\t" << (error->m?error->m:"NA") << endl
-            X(domain);
-            X(code);
-            XS(message);
-            X(level);
-            XS(file);
-            X(line);
-            XS(str1);
-            XS(str2);
-            XS(str3);
-            X(int1);
-            X(int2);
-            X(ctxt);
-            X(node);
-#undef X
-#undef XS
+          // error->message is NL terminated
+          std::string err( str::form( "%s[%d] %s", Pathname::basename(error->file).c_str(), error->line,
+                                      str::stripSuffix( error->message, "\n" ).c_str() ) );
+          structuredErrors.push_back( err );
+          WAR << err << endl;
         }
-#endif
       }
 
       struct ParseException : public Exception
       {
-	ParseException()
-	: Exception( "Parse error: " + ( structuredErrors.empty() ? std::string("unknown error"): structuredErrors.back() ) )
-	{
-	  for_( it, structuredErrors.begin(), --structuredErrors.end() )
-	    addHistory( *it );
-	}
+        ParseException()
+        : Exception( "Parse error: " + ( structuredErrors.empty() ? std::string("unknown error"): structuredErrors.back() ) )
+        {
+          for_( it, structuredErrors.begin(), --structuredErrors.end() )
+            addHistory( *it );
+        }
       };
 
       /////////////////////////////////////////////////////////////////
