@@ -12,11 +12,13 @@
 #ifndef zypp_source_yum_RepomdFileReader_H
 #define zypp_source_yum_RepomdFileReader_H
 
+#include <set>
+
 #include <zypp/base/PtrTypes.h>
 #include <zypp/base/NonCopyable.h>
 #include <zypp/base/Function.h>
 
-#include <zypp/OnMediaLocation.h>
+#include <zypp-core/OnMediaLocation>
 
 namespace zypp
 {
@@ -41,17 +43,26 @@ namespace zypp
 
    /**
     * CTOR. Creates also \ref xml::Reader and starts reading.
-    * 
+    *
     * \param repomd_file is the repomd.xml file you want to read
     * \param callback is a function.
     *
     * \see RepomdFileReader::ProcessResource
     */
     RepomdFileReader( const Pathname & repomd_file, const ProcessResource & callback );
+    /** \overload Quick parsing keywords and keyhints. */
+    RepomdFileReader( const Pathname & repomd_file );
 
     /** DTOR */
     ~RepomdFileReader();
 
+  public:
+    /** repo keywords parsed on the fly */
+    const std::set<std::string> & keywords() const;
+
+    /** gpg key hits shipped in keywords (bsc#1184326) */
+    std::vector<std::pair<std::string,std::string>> keyhints() const;
+
   private:
     class Impl;
     RW_pointer<Impl,rw_pointer::Scoped<Impl> > _pimpl;
