@@ -41,7 +41,7 @@ namespace zypp
      *   system:       1
      * \endcode
     */
-    struct PoolStats : public std::unary_function<ResObject::constPtr, void>
+    struct PoolStats
     {
       void operator()( ResObject::constPtr ptr )
       {
@@ -71,8 +71,7 @@ namespace zypp
                                   TIterator begin_r, TIterator end_r )
     {
       pool::PoolStats stats;
-      std::for_each( begin_r, end_r,
-                     functor::functorRef<void,ResObject::constPtr>(stats) );
+      std::for_each( begin_r, end_r, std::ref(stats) );
       return str << stats;
     }
 
