@@ -13,9 +13,9 @@
 #include <zypp/Url.h>
 #include <zypp/Pathname.h>
 #include <zypp/Fetcher.h>
-#include <zypp/OnMediaLocation.h>
+#include <zypp-core/OnMediaLocation>
 #include <zypp/MediaSetAccess.h>
-#include <zypp/ProgressData.h>
+#include <zypp-core/ui/ProgressData>
 #include <zypp/RepoInfo.h>
 #include <zypp/RepoStatus.h>
 #include <zypp/repo/Downloader.h>
@@ -68,9 +68,9 @@ namespace zypp
         RepoStatus status( MediaSetAccess & media_r ) override;
 
       private:
-	class Impl;
-	friend class Impl;
-	Pathname _deltaDir;
+        class Impl;
+        friend class Impl;
+        Pathname _deltaDir;
       };
 
     } // ns yum
