@@ -258,9 +258,9 @@ namespace zypp
         return str << "search nothing";
 
       if ( obj.attr() )
-        str << "seach " << obj.attr() << " in ";
+        str << "search " << obj.attr() << " in ";
       else
-        str << "seach ALL in ";
+        str << "search ALL in ";
 
       if ( obj.solvable() )
         return str << obj.solvable();
@@ -321,7 +321,7 @@ namespace zypp
         {
           _dip = new ::Dataiterator;
           ::dataiterator_init_clone( _dip, rhs._dip );
-	  ::dataiterator_strdup( _dip );
+          ::dataiterator_strdup( _dip );
         }
       }
 
@@ -597,10 +597,10 @@ namespace zypp
             break;
 
           case REPOKEY_TYPE_DIRSTRARRAY:
-	    // may or may not be stringified depending on SEARCH_FILES flag
+            // may or may not be stringified depending on SEARCH_FILES flag
             return( _dip->flags & SEARCH_FILES
-		    ? _dip->kv.str
-		    : ::repodata_dir2str( _dip->data, _dip->kv.id, _dip->kv.str ) );
+                    ? _dip->kv.str
+                    : ::repodata_dir2str( _dip->data, _dip->kv.id, _dip->kv.str ) );
             break;
         }
       }
@@ -766,15 +766,15 @@ namespace zypp
     {
       if ( _dip )
       {
-	if ( ! ::dataiterator_step( _dip.get() ) )
-	{
-	  _dip.reset();
-	  base_reference() = 0;
-	}
-	else
-	{
-	  ::dataiterator_strdup( _dip.get() );
-	}
+        if ( ! ::dataiterator_step( _dip.get() ) )
+        {
+          _dip.reset();
+          base_reference() = 0;
+        }
+        else
+        {
+          ::dataiterator_strdup( _dip.get() );
+        }
       }
     }
 
