@@ -15,7 +15,7 @@
 #include <iosfwd>
 
 #include <zypp/base/PtrTypes.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DefaultIntegral>
 
 #include <zypp/sat/detail/PoolMember.h>
 #include <zypp/sat/SolvAttr.h>
@@ -159,7 +159,7 @@ namespace zypp
 
         /** TransformIterator returning an \ref iterator vaue of type \c TResult. */
         template<class TResult, class TAttr = TResult>
-	class TransformIterator;
+        class TransformIterator;
         //@}
 
       public:
@@ -331,7 +331,7 @@ namespace zypp
           detail::CDataiterator * get()        const  { return _dip; }
           const std::string & getstr()   const  { return _mstring; }
 
-	private:
+        private:
           detail::CDataiterator * _dip;
           std::string _mstring;
       };
@@ -432,9 +432,9 @@ namespace zypp
          *
          * \note Unfortunately the underlying libsolv dataiterator as returned
          * by \ref subBegin and \ref subFind loses some context when being created.
-         * Thus it's not possible to invoke \ref subBegin and \ref subFind on an
+         * Thus, it's not possible to invoke \ref subBegin and \ref subFind on an
          * iterator that was previously returned by one of those methods. The result
-         * will be an \c end iterator. For the same reason it is not possible for an
+         * will be an \c end iterator. For the same reason, it is not possible for an
          * iterator to leave the sub-structure again.
          *
          * \code
@@ -512,7 +512,7 @@ namespace zypp
          * via \ref c_str and \ref asString.
          */
         IdString idStr() const;
-	/** \overload Directly returning the \c Id */
+        /** \overload Directly returning the \c Id */
         detail::IdType id() const
         { return idStr().id(); }
 
@@ -543,7 +543,7 @@ namespace zypp
       public:
         /**
          * C-tor taking over ownership of the passed \c detail::CDataiterator
-         * and doing it's first iteration (::dataiterator_step)
+         * and doing its first iteration (::dataiterator_step)
          */
         iterator( detail::DIWrap & dip_r );
 
