@@ -56,7 +56,8 @@ namespace zypp
       typedef sat::detail::SolvableIdType IdType;
 
       static const IdString retractedToken;	///< Indicator provides `retracted-patch-package()`
-      static const IdString ptfToken;		///< Indicator provides `ptf()`
+      static const IdString ptfMasterToken;	///< Indicator provides `ptf()`
+      static const IdString ptfPackageToken;	///< Indicator provides `ptf-package()`
 
     public:
       /** Default ctor creates \ref noSolvable.*/
@@ -80,7 +81,7 @@ namespace zypp
     public:
       /** The identifier.
        * This is the solvables \ref name, \b except for packages and
-       * source packes, prefixed by it's \ref kind.
+       * source packes, prefixed by its \ref kind.
        */
       IdString ident()const;
 
@@ -147,12 +148,40 @@ namespace zypp
       /** Whether this solvable triggers the reboot-needed hint if installed/updated. */
       bool isNeedreboot() const;
 
+      /** \name Blacklisted packages.
+       *
+       * Blacklisted packages are visible in a repository, but no matter how good they
+       * apparently look like, they must not be considered during normal operations.
+       *
+       * Under normal conditions the resolver will avoid selecting blacklisted packages.
+       * To install a blacklisted package it must be selected explicitly. Whether this
+       * is a good idea, depends on the reason for having been blacklisted:
+       *
+       * - RETRACTED packages are usually buggy packages/patches which have been released
+       * and can not be removed from the public repositories anymore. Nevertheless those
+       * packages should not be installed.
+       *
+       * - PTFs usually contain special features or fixes which are not yet released as
+       * an official patch upadate. Installing a PTF will prevent its packages from being
+       * updated until you decide to remove the PTF and follow the official releases again.
+       */
+      //@{
+      /** Whether this solvable is blacklisted (retracted,ptf,...). */
+      bool isBlacklisted() const;
+
       /** Whether this solvable is retracted (provides \ref retractedToken). */
       bool isRetracted() const;
 
-      /** Whether this solvable is a PTF (provides \ref ptfToken). */
+      /** Whether this solvable belongs to a PTF (provides \ref ptfMasterToken or \ref ptfPackageToken). */
       bool isPtf() const;
 
+      /** Subset of \ref isPtf (provides \ref ptfMasterToken). */
+      bool isPtfMaster() const;
+
+      /** Subset of \ref isPtf (provides \ref ptfPackageToken). */
+      bool isPtfPackage() const;
+      //@}
+
       /** The items build time. */
       Date buildtime() const;
 
@@ -200,19 +229,19 @@ namespace zypp
       /** Return \ref Capabilities selected by \ref Dep constant. */
       Capabilities dep( Dep which_r ) const
       {
-	switch( which_r.inSwitch() )
-	{
-	  case Dep::PROVIDES_e:    return provides();    break;
-	  case Dep::REQUIRES_e:    return requires();    break;
-	  case Dep::CONFLICTS_e:   return conflicts();   break;
-	  case Dep::OBSOLETES_e:   return obsoletes();   break;
-	  case Dep::RECOMMENDS_e:  return recommends();  break;
-	  case Dep::SUGGESTS_e:    return suggests();    break;
-	  case Dep::ENHANCES_e:    return enhances();    break;
-	  case Dep::SUPPLEMENTS_e: return supplements(); break;
-	  case Dep::PREREQUIRES_e: return prerequires(); break;
-	}
-	return Capabilities();
+        switch( which_r.inSwitch() )
+        {
+          case Dep::PROVIDES_e:    return provides();    break;
+          case Dep::REQUIRES_e:    return requires();    break;
+          case Dep::CONFLICTS_e:   return conflicts();   break;
+          case Dep::OBSOLETES_e:   return obsoletes();   break;
+          case Dep::RECOMMENDS_e:  return recommends();  break;
+          case Dep::SUGGESTS_e:    return suggests();    break;
+          case Dep::ENHANCES_e:    return enhances();    break;
+          case Dep::SUPPLEMENTS_e: return supplements(); break;
+          case Dep::PREREQUIRES_e: return prerequires(); break;
+        }
+        return Capabilities();
       }
       /** \overload operator[] */
       Capabilities operator[]( Dep which_r ) const
@@ -315,21 +344,21 @@ namespace zypp
       class SplitIdent
       {
       public:
-	SplitIdent() {}
-	SplitIdent( IdString ident_r );
-	SplitIdent( const char * ident_r );
-	SplitIdent( const std::string & ident_r );
-	SplitIdent( ResKind kind_r, IdString name_r );
-	SplitIdent( ResKind kind_r, const C_Str & name_r );
+        SplitIdent() {}
+        SplitIdent( IdString ident_r );
+        SplitIdent( const char * ident_r );
+        SplitIdent( const std::string & ident_r );
+        SplitIdent( ResKind kind_r, IdString name_r );
+        SplitIdent( ResKind kind_r, const C_Str & name_r );
 
-	IdString ident() const { return _ident; }
-	ResKind  kind()  const { return _kind; }
-	IdString name()  const { return _name; }
+        IdString ident() const { return _ident; }
+        ResKind  kind()  const { return _kind; }
+        IdString name()  const { return _name; }
 
       private:
-	IdString  _ident;
-	ResKind   _kind;
-	IdString  _name;
+        IdString  _ident;
+        ResKind   _kind;
+        IdString  _name;
       };
 
     public:
@@ -444,8 +473,8 @@ namespace zypp
       int res = 0;
       if ( lhs != rhs )
       {
-	if ( (res = lhs.kind().compare( rhs.kind() )) == 0 )
-	  res = lhs.name().compare( rhs.name() );
+        if ( (res = lhs.kind().compare( rhs.kind() )) == 0 )
+          res = lhs.name().compare( rhs.name() );
       }
       return res;
     }
@@ -455,7 +484,7 @@ namespace zypp
     {
       int res = compareByN( lhs, rhs );
       if ( res == 0 )
-	res = lhs.edition().compare( rhs.edition() );
+        res = lhs.edition().compare( rhs.edition() );
       return res;
     }
 
@@ -464,7 +493,7 @@ namespace zypp
     {
       int res = compareByNVR( lhs, rhs );
       if ( res == 0 )
-	res = lhs.arch().compare( rhs.arch() );
+        res = lhs.arch().compare( rhs.arch() );
       return res;
     }
 
@@ -472,10 +501,11 @@ namespace zypp
     namespace detail
     {
       ///////////////////////////////////////////////////////////////////
-      //
-      //	CLASS NAME : SolvableIterator
-      //
-      /** */
+      /// \class SolvableIterator
+      /// \brief Iterate over valid Solvables in the pool.
+      /// If the Solvable passed to the ctor is not valid, advance
+      /// to the next valid solvable (or Solvable::noSolvable if the
+      /// end is reached,
       class SolvableIterator : public boost::iterator_adaptor<
           SolvableIterator                   // Derived
           , CSolvable*                       // Base
@@ -486,16 +516,16 @@ namespace zypp
       {
         public:
           SolvableIterator()
-          : SolvableIterator::iterator_adaptor_( 0 )
+          : SolvableIterator::iterator_adaptor_( nullptr )
           {}
 
           explicit SolvableIterator( const Solvable & val_r )
-          : SolvableIterator::iterator_adaptor_( 0 )
-          { assignVal( val_r ); }
+          : SolvableIterator::iterator_adaptor_( nullptr )
+          { initialAssignVal( val_r ); }
 
           explicit SolvableIterator( SolvableIdType id_r )
-          : SolvableIterator::iterator_adaptor_( 0 )
-          { assignVal( Solvable( id_r ) ); }
+          : SolvableIterator::iterator_adaptor_( nullptr )
+          { initialAssignVal( Solvable(id_r) ); }
 
         private:
           friend class boost::iterator_core_access;
@@ -507,6 +537,9 @@ namespace zypp
           { assignVal( _val.nextInPool() ); }
 
         private:
+          void initialAssignVal( const Solvable & val_r )
+          { assignVal( val_r ? val_r : val_r.nextInPool() ); }
+
           void assignVal( const Solvable & val_r )
           { _val = val_r; base_reference() = _val.get(); }
 
