@@ -15,7 +15,7 @@
 
 #include <zypp/sat/Solvable.h>
 #include <zypp/Repository.h>
-#include <zypp/OnMediaLocation.h>
+#include <zypp-core/OnMediaLocation>
 #include <zypp/ByteCount.h>
 #include <zypp/CheckSum.h>
 #include <zypp/CpeId.h>
@@ -81,8 +81,12 @@ namespace zypp
       bool		identIsAutoInstalled() const		{ return satSolvable().identIsAutoInstalled(); }
       bool		multiversionInstall() const		{ return satSolvable().multiversionInstall(); }
       bool              isNeedreboot() const			{ return satSolvable().isNeedreboot(); }
+
+      bool		isBlacklisted() const			{ return satSolvable().isBlacklisted(); }
       bool		isRetracted() const			{ return satSolvable().isRetracted(); }
       bool		isPtf() const				{ return satSolvable().isPtf(); }
+      bool		isPtfMaster() const			{ return satSolvable().isPtfMaster(); }
+      bool		isPtfPackage() const			{ return satSolvable().isPtfPackage(); }
 
       Date		buildtime() const			{ return satSolvable().buildtime(); }
       Date		installtime() const			{ return satSolvable().installtime(); }
