@@ -16,7 +16,7 @@
 #include <zypp/base/PtrTypes.h>
 #include <zypp/base/Flags.h>
 #include <zypp/base/Iterator.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <zypp-core/base/DefaultIntegral>
 
 #include <zypp/sat/SolvIterMixin.h>
 #include <zypp/sat/Solvable.h>
@@ -61,18 +61,18 @@ namespace zypp
        /** Type of (rpm) action to perform in a \ref Step. */
        enum StepType
        {
-	 TRANSACTION_IGNORE		= 0x00,	/**< [ ] Nothing (includes implicit deletes due to obsoletes and non-package actions) */
-	 TRANSACTION_ERASE		= 0x10,	/**< [-] Delete item */
-	 TRANSACTION_INSTALL		= 0x20,	/**< [+] Install(update) item */
-	 TRANSACTION_MULTIINSTALL	= 0x30	/**< [M] Install(multiversion) item (\see \ref ZConfig::multiversion) */
+         TRANSACTION_IGNORE		= 0x00,	/**< [ ] Nothing (includes implicit deletes due to obsoletes and non-package actions) */
+         TRANSACTION_ERASE		= 0x10,	/**< [-] Delete item */
+         TRANSACTION_INSTALL		= 0x20,	/**< [+] Install(update) item */
+         TRANSACTION_MULTIINSTALL	= 0x30	/**< [M] Install(multiversion) item (\see \ref ZConfig::multiversion) */
        };
 
        /** \ref Step action result. */
        enum StepStage
        {
-	 STEP_TODO	= (1 << 0),	/**< [__] unprocessed */
-	 STEP_DONE	= (1 << 1),	/**< [OK] success */
-	 STEP_ERROR	= (1 << 2),	/**< [**] error */
+         STEP_TODO	= (1 << 0),	/**< [__] unprocessed */
+         STEP_DONE	= (1 << 1),	/**< [OK] success */
+         STEP_ERROR	= (1 << 2),	/**< [**] error */
        };
 
        ZYPP_DECLARE_FLAGS(StepStages,StepStage);
@@ -92,94 +92,94 @@ namespace zypp
         ~Transaction();
 
       public:
-	/** Whether transaction actually contains data and also fits the current pools content. */
-	bool valid() const;
+        /** Whether transaction actually contains data and also fits the current pools content. */
+        bool valid() const;
 
         /**  Validate object in a boolean context: valid */
         explicit operator bool() const
         { return valid(); }
 
-	/** Order transaction steps for commit.
-	 * It's cheap to call it for an aleready ordered \ref Transaction.
-	 * This invalidates outstanding iterators. Returns whether
-	 * \ref Transaction is \ref valid.
-	 */
-	bool order();
+        /** Order transaction steps for commit.
+         * It's cheap to call it for an aleready ordered \ref Transaction.
+         * This invalidates outstanding iterators. Returns whether
+         * \ref Transaction is \ref valid.
+         */
+        bool order();
 
-	/** Whether the transaction contains any steps. */
-	bool empty() const;
+        /** Whether the transaction contains any steps. */
+        bool empty() const;
 
-	/** Number of steps in transaction steps. */
-	size_t size() const;
+        /** Number of steps in transaction steps. */
+        size_t size() const;
 
-	typedef detail::Transaction_iterator iterator;
-	typedef detail::Transaction_const_iterator const_iterator;
+        typedef detail::Transaction_iterator iterator;
+        typedef detail::Transaction_const_iterator const_iterator;
 
-	/** Iterator to the first \ref TransactionStep */
-	const_iterator begin() const;
-	/** \overload */
-	iterator begin();
+        /** Iterator to the first \ref TransactionStep */
+        const_iterator begin() const;
+        /** \overload */
+        iterator begin();
 
-	/** Iterator behind the last \ref TransactionStep */
-	const_iterator end() const;
-	/** \overload */
-	iterator end();
+        /** Iterator behind the last \ref TransactionStep */
+        const_iterator end() const;
+        /** \overload */
+        iterator end();
 
-	/** Return iterator pointing to \a solv_r or \ref end. */
-	const_iterator find( const sat::Solvable & solv_r ) const;
-	iterator find( const sat::Solvable & solv_r );
-	/** \overload */
-	const_iterator find( const ResObject::constPtr & resolvable_r ) const;
-	iterator find( const ResObject::constPtr & resolvable_r );
-	/** \overload */
-	const_iterator find( const PoolItem & pi_r ) const;
-	iterator find( const PoolItem & pi_r );
+        /** Return iterator pointing to \a solv_r or \ref end. */
+        const_iterator find( const sat::Solvable & solv_r ) const;
+        iterator find( const sat::Solvable & solv_r );
+        /** \overload */
+        const_iterator find( const ResObject::constPtr & resolvable_r ) const;
+        iterator find( const ResObject::constPtr & resolvable_r );
+        /** \overload */
+        const_iterator find( const PoolItem & pi_r ) const;
+        iterator find( const PoolItem & pi_r );
 
       public:
-	/** \name Iterate action steps (omit TRANSACTION_IGNORE steps).
-	 *
-	 * All these methods allow to pass an optional OR'd combination of
-	 * \ref StepStages as filter. Per default all steps are processed/counted.
-	 *
-	 * \code
-	 *    Transaction trans;
-	 *    for_( it, trans.actionBegin(~sat::Transaction::STEP_DONE), trans.actionEnd() )
-	 *    {
-	 *       ... // process all steps not DONE (ERROR and TODO)
-	 *    }
-	 * \endcode
-	 */
-	//@{
-	struct FilterAction;
-	typedef filter_iterator<FilterAction,const_iterator> action_iterator;
+        /** \name Iterate action steps (omit TRANSACTION_IGNORE steps).
+         *
+         * All these methods allow to pass an optional OR'd combination of
+         * \ref StepStages as filter. Per default all steps are processed/counted.
+         *
+         * \code
+         *    Transaction trans;
+         *    for_( it, trans.actionBegin(~sat::Transaction::STEP_DONE), trans.actionEnd() )
+         *    {
+         *       ... // process all steps not DONE (ERROR and TODO)
+         *    }
+         * \endcode
+         */
+        //@{
+        struct FilterAction;
+        typedef filter_iterator<FilterAction,const_iterator> action_iterator;
 
-	/** Whether the [filtered] transaction contains any steps . */
-	bool actionEmpty( StepStages filter_r = StepStages() ) const;
+        /** Whether the [filtered] transaction contains any steps . */
+        bool actionEmpty( StepStages filter_r = StepStages() ) const;
 
-	/** Number of steps in [filtered] transaction steps. */
-	size_t actionSize( StepStages filter_r = StepStages() ) const;
+        /** Number of steps in [filtered] transaction steps. */
+        size_t actionSize( StepStages filter_r = StepStages() ) const;
 
-	/** Pointer to the 1st action step in [filtered] transaction. */
-	action_iterator actionBegin( StepStages filter_r = StepStages() ) const;
+        /** Pointer to the 1st action step in [filtered] transaction. */
+        action_iterator actionBegin( StepStages filter_r = StepStages() ) const;
 
-	/** Pointer behind the last action step in transaction. */
-	action_iterator actionEnd() const;
+        /** Pointer behind the last action step in transaction. */
+        action_iterator actionEnd() const;
 
-	/** Iterate the [filtered] transaction steps. */
-	Iterable<action_iterator> action( StepStages filter_r = StepStages() ) const;
-	//@}
+        /** Iterate the [filtered] transaction steps. */
+        Iterable<action_iterator> action( StepStages filter_r = StepStages() ) const;
+        //@}
 
       public:
-	/** Return all packages that would be installed after the transaction is run.
-	 * The new packages are put at the head of the queue, the number of new
-	 * packages is returned. (wraps libsolv::transaction_installedresult) */
-	int installedResult( Queue & result_r ) const;
+        /** Return all packages that would be installed after the transaction is run.
+         * The new packages are put at the head of the queue, the number of new
+         * packages is returned. (wraps libsolv::transaction_installedresult) */
+        int installedResult( Queue & result_r ) const;
 
-	/** Return the ident strings of all packages that would be auto-installed after the transaction is run. */
-	StringQueue autoInstalled() const;
+        /** Return the ident strings of all packages that would be auto-installed after the transaction is run. */
+        StringQueue autoInstalled() const;
 
-	/** Set the ident strings of all packages that would be auto-installed after the transaction is run. */
-	void autoInstalled( const StringQueue & queue_r );
+        /** Set the ident strings of all packages that would be auto-installed after the transaction is run. */
+        void autoInstalled( const StringQueue & queue_r );
 
       public:
         /** Implementation  */
@@ -220,58 +220,58 @@ namespace zypp
       friend std::ostream & operator<<( std::ostream & str, const Step & obj );
 
       public:
-	Step();
-	Step( const RW_pointer<Impl> & pimpl_r, detail::IdType id_r )
-	  : _solv( id_r )
-	  , _pimpl( pimpl_r )
-	{}
+        Step();
+        Step( const RW_pointer<Impl> & pimpl_r, detail::IdType id_r )
+          : _solv( id_r )
+          , _pimpl( pimpl_r )
+        {}
 
       public:
-	/** Type of action to perform in this step. */
-	StepType stepType() const;
+        /** Type of action to perform in this step. */
+        StepType stepType() const;
 
-	/** Step action result. */
-	StepStage stepStage() const;
+        /** Step action result. */
+        StepStage stepStage() const;
 
-	/** Set step action result. */
-	void stepStage( StepStage val_r );
+        /** Set step action result. */
+        void stepStage( StepStage val_r );
 
-	/** Return the corresponding \ref Solvable.
-	 * Returns \ref Solvable::noSolvable if the item is meanwhile deleted and
-	 * was removed from the pool. \see Post mortem acccess to @System solvables.
-	 */
-	Solvable satSolvable() const
-	{ return _solv; }
+        /** Return the corresponding \ref Solvable.
+         * Returns \ref Solvable::noSolvable if the item is meanwhile deleted and
+         * was removed from the pool. \see Post mortem acccess to @System solvables.
+         */
+        Solvable satSolvable() const
+        { return _solv; }
 
-	/** \name Post mortem acccess to @System solvables
-	 * \code
-	 *   Transaction::Step step;
-	 *   if ( step.satSolvable() )
-	 *     std::cout << step.satSolvable() << endl;
-	 *   else
-	 *     std::cout << step.ident() << endl; // deleted @System solvable
-	 * \endcode
-	 */
-	//@{
-	/** \see \ref sat::Solvable::ident. */
-	IdString ident() const;
+        /** \name Post mortem acccess to @System solvables
+         * \code
+         *   Transaction::Step step;
+         *   if ( step.satSolvable() )
+         *     std::cout << step.satSolvable() << endl;
+         *   else
+         *     std::cout << step.ident() << endl; // deleted @System solvable
+         * \endcode
+         */
+        //@{
+        /** \see \ref sat::Solvable::ident. */
+        IdString ident() const;
 
-	/** \see \ref sat::Solvable::edition. */
-	Edition edition() const;
+        /** \see \ref sat::Solvable::edition. */
+        Edition edition() const;
 
-	/** \see \ref sat::Solvable::arch. */
-	Arch arch() const;
-	//@}
+        /** \see \ref sat::Solvable::arch. */
+        Arch arch() const;
+        //@}
 
-	/** Implicit conversion to \ref Solvable */
-	operator const Solvable &() const { return _solv; }
-	/** \overload nonconst */
-	operator Solvable &() { return _solv; }
+        /** Implicit conversion to \ref Solvable */
+        operator const Solvable &() const { return _solv; }
+        /** \overload nonconst */
+        operator Solvable &() { return _solv; }
 
       private:
-	Solvable _solv;
-	/** Pointer to implementation */
-	RW_pointer<Impl> _pimpl;
+        Solvable _solv;
+        /** Pointer to implementation */
+        RW_pointer<Impl> _pimpl;
     };
 
     /** \relates Transaction::Step Stream output */
@@ -297,23 +297,23 @@ namespace zypp
       , Transaction::Step		// Reference
       >
       {
-	public:
-	  Transaction_iterator();
-	  Transaction_iterator( const RW_pointer<Transaction::Impl> & pimpl_r, base_type id_r )
-	  : Transaction_iterator::iterator_adaptor_( id_r )
-	  , _pimpl( pimpl_r )
-	  {}
+        public:
+          Transaction_iterator();
+          Transaction_iterator( const RW_pointer<Transaction::Impl> & pimpl_r, base_type id_r )
+          : Transaction_iterator::iterator_adaptor_( id_r )
+          , _pimpl( pimpl_r )
+          {}
 
-	private:
-	  friend class boost::iterator_core_access;
+        private:
+          friend class boost::iterator_core_access;
 
-	  reference dereference() const
-	  { return Transaction::Step( _pimpl, *base() ); }
+          reference dereference() const
+          { return Transaction::Step( _pimpl, *base() ); }
 
-	private:
-	  friend class Transaction_const_iterator;
-	  /** Pointer to implementation */
-	  RW_pointer<Transaction::Impl> _pimpl;
+        private:
+          friend class Transaction_const_iterator;
+          /** Pointer to implementation */
+          RW_pointer<Transaction::Impl> _pimpl;
       };
 
      /** \ref Transaction const_iterator.
@@ -326,23 +326,23 @@ namespace zypp
       , const Transaction::Step		// Reference
       >
       {
-	public:
-	  Transaction_const_iterator();
-	  Transaction_const_iterator( const Transaction_iterator & iter_r );
-	  Transaction_const_iterator( const RW_pointer<Transaction::Impl> & pimpl_r, base_type id_r )
-	  : Transaction_const_iterator::iterator_adaptor_( id_r )
-	  , _pimpl( pimpl_r )
-	  {}
+        public:
+          Transaction_const_iterator();
+          Transaction_const_iterator( const Transaction_iterator & iter_r );
+          Transaction_const_iterator( const RW_pointer<Transaction::Impl> & pimpl_r, base_type id_r )
+          : Transaction_const_iterator::iterator_adaptor_( id_r )
+          , _pimpl( pimpl_r )
+          {}
 
-	private:
-	  friend class boost::iterator_core_access;
+        private:
+          friend class boost::iterator_core_access;
 
-	  reference dereference() const
-	  { return Transaction::Step( _pimpl, *base() ); }
+          reference dereference() const
+          { return Transaction::Step( _pimpl, *base() ); }
 
-	private:
-	  /** Pointer to implementation */
-	  RW_pointer<Transaction::Impl> _pimpl;
+        private:
+          /** Pointer to implementation */
+          RW_pointer<Transaction::Impl> _pimpl;
       };
 
        /////////////////////////////////////////////////////////////////
@@ -369,9 +369,9 @@ namespace zypp
 
       bool operator()( const Transaction::Step & step_r ) const
       {
-	if ( step_r.stepType() == Transaction::TRANSACTION_IGNORE )
-	  return false; // no action
-	return !_filter || _filter.testFlag( step_r.stepStage() );
+        if ( step_r.stepType() == Transaction::TRANSACTION_IGNORE )
+          return false; // no action
+        return !_filter || _filter.testFlag( step_r.stepStage() );
       }
 
       StepStages _filter;
@@ -390,7 +390,7 @@ namespace zypp
     {
       size_t cnt = 0;
       for_( it, actionBegin( filter_r ), actionEnd() )
-	++cnt;
+        ++cnt;
       return cnt;
     }
 
