@@ -22,7 +22,6 @@
 #include <zypp/ZYppCommit.h>
 
 #include <zypp/Pathname.h>
-#include <zypp/media/MediaAccess.h>
 #include <zypp/Target.h>
 #include <zypp/target/rpm/RpmDb.h>
 #include <zypp/target/TargetException.h>
@@ -135,9 +134,7 @@ namespace zypp
 
       /** Overload to realize stream output. */
       virtual std::ostream & dumpOn( std::ostream & str ) const
-      {
-        return str << "TargetImpl";
-      }
+      { return str << "Target(" << root() << ")"; }
 
       /** The RPM database */
       rpm::RpmDb & rpm();
@@ -209,8 +206,14 @@ namespace zypp
     private:
       /** Commit ordered changes (internal helper) */
       void commit( const ZYppCommitPolicy & policy_r,
-		   CommitPackageCache & packageCache_r,
-		   ZYppCommitResult & result_r );
+                   CommitPackageCache & packageCache_r,
+                   ZYppCommitResult & result_r );
+
+      /** Commit ordered changes (internal helper) */
+      void commitInSingleTransaction( const ZYppCommitPolicy & policy_r,
+        CommitPackageCache & packageCache_r,
+        ZYppCommitResult & result_r );
+
 
       /** Commit helper checking for file conflicts after download. */
       void commitFindFileConflicts( const ZYppCommitPolicy & policy_r, ZYppCommitResult & result_r );
