@@ -26,6 +26,7 @@ extern "C"
 #include <zypp/base/NonCopyable.h>
 #include <zypp/base/PtrTypes.h>
 #include <zypp/target/rpm/librpm.h>
+#include <zypp-core/ByteArray.h>
 
 namespace zypp
 {
@@ -87,9 +88,13 @@ public:
 
   int int_val( tag tag_r ) const;
 
+  ByteArray blob_val ( tag tag_r ) const;
+
   std::string string_val( tag tag_r ) const;
   std::string format ( const char * fmt) const;
 
+  Header get() const;
+
 public:
 
   std::list<std::string> stringList_val( tag tag_r ) const;
