@@ -44,6 +44,7 @@ extern "C"
 
 #include <zypp/target/rpm/RpmDb.h>
 #include <zypp/target/rpm/RpmCallbacks.h>
+#include <zypp/target/RpmPostTransCollector.h>
 
 #include <zypp/HistoryLog.h>
 #include <zypp/target/rpm/librpmDb.h>
@@ -64,6 +65,10 @@ using namespace zypp::filesystem;
 
 #define WORKAROUNDRPMPWDBUG
 
+// bsc#1216091 indicates that 'rpm --runposttrans' does not execute the
+// scripts chroot if --root is used. We disable it if --root is not /.
+#define WORKAROUNDDUMPPOSTTRANSBUG
+
 #undef ZYPP_BASE_LOGGER_LOGGROUP
 #define ZYPP_BASE_LOGGER_LOGGROUP "librpmDb"
 
@@ -365,7 +370,7 @@ void RpmDb::closeDatabase()
   ///////////////////////////////////////////////////////////////////
   // Block further database access
   ///////////////////////////////////////////////////////////////////
-  librpmDb::blockAccess();
+  librpmDb::blockAccess( root(), dbPath() );
 
   ///////////////////////////////////////////////////////////////////
   // Uninit
@@ -1648,12 +1653,16 @@ void RpmDb::processConfigFiles(const std::string& line, const std::string& name,
 
 ///////////////////////////////////////////////////////////////////
 //
-//
 //	METHOD NAME : RpmDb::installPackage
-//	METHOD TYPE : PMError
 //
 void RpmDb::installPackage( const Pathname & filename, RpmInstFlags flags )
+{ installPackage( filename, flags, nullptr ); }
+
+void RpmDb::installPackage( const Pathname & filename, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r )
 {
+  if ( postTransCollector_r && postTransCollector_r->hasPosttransScript( filename ) )
+    flags |= rpm::RPMINST_NOPOSTTRANS;  // Just set the flag here. In \ref doInstallPackage we collect what else is needed.
+
   callback::SendReport<RpmInstallReport> report;
 
   report->start(filename);
@@ -1661,7 +1670,7 @@ void RpmDb::installPackage( const Pathname & filename, RpmInstFlags flags )
   do
     try
     {
-      doInstallPackage(filename, flags, report);
+      doInstallPackage( filename, flags, postTransCollector_r, report );
       report->finish();
       break;
     }
@@ -1682,7 +1691,7 @@ void RpmDb::installPackage( const Pathname & filename, RpmInstFlags flags )
   while (true);
 }
 
-void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, callback::SendReport<RpmInstallReport> & report )
+void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r, callback::SendReport<RpmInstallReport> & report )
 {
   FAILIFNOTINITIALIZED;
   HistoryLog historylog;
@@ -1703,6 +1712,14 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
 
   // run rpm
   RpmArgVec opts;
+#if defined(WORKAROUNDDUMPPOSTTRANSBUG)
+  if ( postTransCollector_r && _root == "/" ) {
+#else
+  if ( postTransCollector_r ) {
+#endif
+    opts.push_back("--define");           // bsc#1041742: Attempt to delay %transfiletrigger(postun|in) execution iff rpm supports it.
+    opts.push_back("_dump_posttrans 1");  // Old rpm ignores the --define, new rpm injects 'dump_posttrans:' lines to collect and execute later.
+  }
   if (flags & RPMINST_NOUPGRADE)
     opts.push_back("-i");
   else
@@ -1754,6 +1771,7 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
   // LEGACY: collect and forward additional rpm output in finish
   std::string rpmmsg;
   std::vector<std::string> configwarnings;	// TODO: immediately process lines rather than collecting
+  std::vector<std::string> runposttrans;	// bsc#1041742: If rpm supports --runposttrans it injects 'dump_posttrans:' lines we do collect
 
   while ( systemReadLine( line ) )
   {
@@ -1764,6 +1782,10 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
       report->progress( percent );
       continue;
     }
+    if ( str::hasPrefix( line, "dump_posttrans:" ) ) {
+      runposttrans.push_back( line );
+      continue;
+    }
     ++lineno;
     cmdout.set( "lineno", lineno );
     report->report( cmdout );
@@ -1782,6 +1804,10 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
     rpmmsg += "[truncated]\n";
 
   int rpm_status = systemStatus();
+  if ( postTransCollector_r && rpm_status == 0 ) {
+    // Before doing anything else, handle any pending %posttrans script or dump_posttrans lines.
+    postTransCollector_r->collectPosttransInfo( filename, runposttrans );
+  }
 
   // evaluate result
   for (std::vector<std::string>::iterator it = configwarnings.begin();
@@ -1830,26 +1856,23 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
 
 ///////////////////////////////////////////////////////////////////
 //
-//
 //	METHOD NAME : RpmDb::removePackage
-//	METHOD TYPE : PMError
 //
 void RpmDb::removePackage( Package::constPtr package, RpmInstFlags flags )
-{
-  // 'rpm -e' does not like epochs
-  return removePackage( package->name()
-                        + "-" + package->edition().version()
-                        + "-" + package->edition().release()
-                        + "." + package->arch().asString(), flags );
+{ removePackage( package, flags, nullptr ); }
+
+void RpmDb::removePackage( const std::string & name_r, RpmInstFlags flags )
+{ removePackage( name_r, flags, nullptr ); }
+
+void RpmDb::removePackage( Package::constPtr package, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r )
+{ // 'rpm -e' does not like epochs
+  removePackage( package->name()
+                 + "-" + package->edition().version()
+                 + "-" + package->edition().release()
+                 + "." + package->arch().asString(), flags, postTransCollector_r );
 }
 
-///////////////////////////////////////////////////////////////////
-//
-//
-//	METHOD NAME : RpmDb::removePackage
-//	METHOD TYPE : PMError
-//
-void RpmDb::removePackage( const std::string & name_r, RpmInstFlags flags )
+void RpmDb::removePackage( const std::string & name_r, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r )
 {
   callback::SendReport<RpmRemoveReport> report;
 
@@ -1858,7 +1881,7 @@ void RpmDb::removePackage( const std::string & name_r, RpmInstFlags flags )
   do
     try
     {
-      doRemovePackage(name_r, flags, report);
+      doRemovePackage( name_r, flags, postTransCollector_r, report );
       report->finish();
       break;
     }
@@ -1879,8 +1902,7 @@ void RpmDb::removePackage( const std::string & name_r, RpmInstFlags flags )
   while (true);
 }
 
-
-void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, callback::SendReport<RpmRemoveReport> & report )
+void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r, callback::SendReport<RpmRemoveReport> & report )
 {
   FAILIFNOTINITIALIZED;
   HistoryLog historylog;
@@ -1905,6 +1927,14 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
 
   // run rpm
   RpmArgVec opts;
+#if defined(WORKAROUNDDUMPPOSTTRANSBUG)
+  if ( postTransCollector_r && _root == "/" ) {
+#else
+  if ( postTransCollector_r ) {
+#endif
+    opts.push_back("--define");           // bsc#1041742: Attempt to delay %transfiletrigger(postun|in) execution iff rpm supports it.
+    opts.push_back("_dump_posttrans 1");  // Old rpm ignores the --define, new rpm injects 'dump_posttrans:' lines to collect and execute later.
+  }
   opts.push_back("-e");
   opts.push_back("--allmatches");
 
@@ -1936,6 +1966,7 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
 
   // LEGACY: collect and forward additional rpm output in finish
   std::string rpmmsg;
+  std::vector<std::string> runposttrans;	// bsc#1041742: If rpm supports --runposttrans it injects 'dump_posttrans:' lines we do collect
 
   // got no progress from command, so we fake it:
   // 5  - command started
@@ -1944,6 +1975,10 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
   report->progress( 5 );
   while (systemReadLine(line))
   {
+    if ( str::hasPrefix( line, "dump_posttrans:" ) ) {
+      runposttrans.push_back( line );
+      continue;
+    }
     ++lineno;
     cmdout.set( "lineno", lineno );
     report->report( cmdout );
@@ -1958,6 +1993,11 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
     rpmmsg += "[truncated]\n";
   report->progress( 50 );
   int rpm_status = systemStatus();
+  if ( postTransCollector_r && rpm_status == 0 ) {
+    // Before doing anything else, handle any pending %posttrans script or dump_posttrans lines.
+    // 'remove' does not trigger %posttrans, but it may trigger %transfiletriggers.
+    postTransCollector_r->collectPosttransInfo( runposttrans );
+  }
 
   if ( rpm_status != 0 )
   {
@@ -1987,6 +2027,62 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
   }
 }
 
+///////////////////////////////////////////////////////////////////
+//
+//	METHOD NAME : RpmDb::runposttrans
+//
+int RpmDb::runposttrans( const Pathname & filename_r, std::function<void(const std::string&)> output_r )
+{
+  FAILIFNOTINITIALIZED;
+  HistoryLog historylog;
+
+  MIL << "RpmDb::runposttrans(" << filename_r << ")" << endl;
+
+  RpmArgVec opts;
+  opts.push_back("-vv");  // want vverbose output to see scriptlet execution in the log
+  opts.push_back("--runposttrans");
+  opts.push_back(filename_r.c_str());
+  run_rpm (opts, ExternalProgram::Stderr_To_Stdout);
+
+  // Tailored to suit RpmPostTransCollector.
+  // It's a pity, but we need all those verbose debug lines just
+  // to figure out which script is currently executed. Otherwise we
+  // can't tell which output belongs to which script.
+  static const str::regex rx( "^D: (%.*): scriptlet start$" );
+  str::smatch what;
+  std::string line;
+  bool silent = true; // discard everything before 1st scriptlet
+  while ( systemReadLine(line) )
+  {
+    if ( not output_r )
+      continue;
+
+    if ( str::startsWith( line, "D:" ) ) {  // rpm debug output
+      if ( str::regex_match( line, what, rx ) ) {
+        // forward ripoff header
+        output_r( "RIPOFF:"+what[1] );
+        if ( silent )
+          silent = false;
+      }
+      continue;
+    }
+    if ( silent ) {
+      continue;
+    }
+    if ( str::startsWith( line, "+ " ) ) {  // shell -x debug output
+      continue;
+    }
+    // forward output line
+    output_r( line );
+  }
+
+  int rpm_status = systemStatus();
+  if ( rpm_status != 0 ) {
+    WAR << "rpm --runposttrans returned " << rpm_status << endl;
+  }
+  return rpm_status;
+}
+
 ///////////////////////////////////////////////////////////////////
 //
 //
