@@ -163,21 +163,34 @@ namespace zypp
       picklist_size_type idx = picklist_size_type(0);
       for ( const auto & pi : picklist() )
       {
-	if ( pi == solv_r )
-	  return idx;
-	++idx;
+        if ( pi == solv_r )
+          return idx;
+        ++idx;
       }
       return picklistNoPos;
     }
 
     ////////////////////////////////////////////////////////////////////////
 
+    bool Selectable::hasBlacklisted() const
+    { return _pimpl->hasBlacklisted(); }
+
+    bool Selectable::hasBlacklistedInstalled() const
+    { return _pimpl->hasBlacklistedInstalled(); }
+
     bool Selectable::hasRetracted() const
     { return _pimpl->hasRetracted(); }
 
     bool Selectable::hasRetractedInstalled() const
     { return _pimpl->hasRetractedInstalled(); }
 
+    bool Selectable::hasPtf() const
+    { return _pimpl->hasPtf(); }
+
+    bool Selectable::hasPtfInstalled() const
+    { return _pimpl->hasPtfInstalled(); }
+
+
     bool Selectable::isUnmaintained() const
     { return _pimpl->isUnmaintained(); }
 
