@@ -34,14 +34,14 @@ namespace zypp
     struct SelectableTraits
     {
       /** Oder on AvailableItemSet.
-       * \li not retracted
+       * \li not blacklisted
        * \li repository priority
        * \li best Arch (arch/noarch changes are ok)
        * \li best Edition
        * \li newer buildtime
        * \li ResObject::constPtr as fallback.
       */
-      struct AVOrder : public std::binary_function<PoolItem,PoolItem,bool>
+      struct AVOrder
       {
         // NOTE: operator() provides LESS semantics to order the set.
         // So LESS means 'prior in set'. We want 'better' archs and
@@ -50,8 +50,8 @@ namespace zypp
         //
         bool operator()( const PoolItem & lhs, const PoolItem & rhs ) const
         {
-	  if ( lhs.isRetracted() != rhs.isRetracted() )
-	    return rhs.isRetracted();
+          if ( lhs.isBlacklisted() != rhs.isBlacklisted() )
+            return rhs.isBlacklisted();
 
           int lprio = lhs->satSolvable().repository().satInternalPriority();
           int rprio = rhs->satSolvable().repository().satInternalPriority();
@@ -70,9 +70,9 @@ namespace zypp
           if ( res )
             return res > 0;
 
-	  lprio = lhs->buildtime();
-	  rprio = rhs->buildtime();
-	  if ( lprio != rprio )
+          lprio = lhs->buildtime();
+          rprio = rhs->buildtime();
+          if ( lprio != rprio )
             return( lprio > rprio );
 
           lprio = lhs->satSolvable().repository().satInternalSubPriority();
@@ -91,7 +91,7 @@ namespace zypp
        * \li newer install time
        * \li ResObject::constPtr as fallback.
       */
-      struct IOrder : public std::binary_function<PoolItem,PoolItem,bool>
+      struct IOrder
       {
         // NOTE: operator() provides LESS semantics to order the set.
         // So LESS means 'prior in set'. We want 'newer' install time
